@@ -19,34 +19,54 @@
 
 #include "expression.h"
 #include "expressionwriter.h"
+#include "vector.h"
 #include "value.h"
 
 #include <KDebug>
 #include <KLocale>
 
-Container::Container(const Container& c) : Object(Object::container)
+char Container::m_typeStr[][10] = {
+		"none",
+		"math",
+		"apply",
+		"declare",
+		"lambda",
+		"bvar",
+		"uplimit",
+		"downlimit",
+		"piece",
+		"piecewise",
+		"otherwise" };
+
+QMap<QString, Container::ContainerType> createNameToType()
+{
+	QMap<QString, Container::ContainerType> ret;
+	ret["apply"]=Container::apply;
+	ret["declare"]=Container::declare;
+	ret["math"]=Container::math;
+	ret["lambda"]=Container::lambda;
+	ret["bvar"]=Container::bvar;
+	ret["uplimit"]=Container::uplimit;
+	ret["downlimit"]=Container::downlimit;
+	ret["piecewise"]=Container::piecewise;
+	ret["piece"]=Container::piece;
+	ret["otherwise"]=Container::otherwise;
+	
+	return ret;
+}
+
+QMap<QString, Container::ContainerType> Container::m_nameToType=createNameToType();
+
+Container::Container(const Container& c) : Object(Object::container), m_cont_type(c.m_cont_type)
 {
 	Q_ASSERT(c.type()==Object::container);
-	if(c.type()!=Object::container) {
-		setType(Object::none);
-		return;
-	}
 	
 	m_params = c.copyParams();
 }
 
-Container::Container(const Object *o) : Object(o->type())
+Container* Container::copy() const
 {
-	Q_ASSERT(o!=0);
-	if(type() == Object::container) {
-		Container *c = (Container*) o;
-		m_cont_type = c->containerType();
-		
-		m_params = c->copyParams();
-	} else {
-		setType(Object::none);
-		m_cont_type = none;
-	}
+	return new Container(*this);
 }
 
 Operator Container::firstOperator() const
@@ -54,7 +74,7 @@ Operator Container::firstOperator() const
 	const_iterator it=m_params.constBegin(), itEnd=m_params.constEnd();
 	for(; it!=itEnd; ++it) {
 		if((*it)->type()==Object::oper) {
-			return Operator(*it);
+			return *static_cast<Operator*>(*it);
 		} else if(it==m_params.constBegin() && m_cont_type==apply && (*it)->type()==Object::variable) {
 			return Operator(Operator::function);
 		}
@@ -88,29 +108,15 @@ QList<Object*> Container::copyParams() const
 {
 	QList<Object*> ret;
 	
-	for(QList<Object*>::const_iterator it=m_params.constBegin(); it!=m_params.constEnd(); ++it) {
-		ret.append(Expression::objectCopy(*it));
+	for(Container::const_iterator it=m_params.constBegin(); it!=m_params.constEnd(); ++it) {
+		ret.append((*it)->copy());
 	}
 	return ret;
 }
 
-enum Container::ContainerType Container::toContainerType(const QString& tag)
+Container::ContainerType Container::toContainerType(const QString& tag)
 {
-	ContainerType ret=none;
-	
-	if(tag=="apply") ret=apply;
-	else if(tag=="declare") ret=declare;
-	else if(tag=="math") ret=math;
-	else if(tag=="lambda") ret=lambda;
-	else if(tag=="bvar") ret=bvar;
-	else if(tag=="uplimit") ret=uplimit;
-	else if(tag=="downlimit") ret=downlimit;
-	else if(tag=="piecewise") ret=piecewise;
-	else if(tag=="piece") ret=piece;
-	else if(tag=="otherwise") ret=otherwise;
-	else if(tag=="vector") ret=vector;
-	
-	return ret;
+	return m_nameToType[tag];
 }
 
 QStringList Container::bvarList() const //NOTE: Should we return Ci's instead of Strings?
@@ -121,7 +127,7 @@ QStringList Container::bvarList() const //NOTE: Should we return Ci's instead of
 	for(it=m_params.constBegin(); it!=m_params.constEnd(); ++it) {
 		if((*it)->isContainer()) {
 			Container* c = (Container*) (*it);
-			if(c->containerType() == Container::bvar)
+			if(c->containerType() == Container::bvar && !c->m_params.isEmpty() && c->m_params[0]->type()==Object::variable)
 				bvars.append(((Ci*)c->m_params[0])->name());
 		}
 	}
@@ -129,24 +135,14 @@ QStringList Container::bvarList() const //NOTE: Should we return Ci's instead of
 	return bvars;
 }
 
-Container* Container::ulimit() const
+Object* Container::ulimit() const
 {
-	for(QList<Object*>::const_iterator it=m_params.begin(); it!=m_params.end(); ++it) {
-		Container *c = (Container*) (*it);
-		if(c->type()==Object::container && c->containerType()==Container::uplimit && c->m_params[0]->type()==Object::value)
-			return (Container*) c->m_params[0];
-	}
-	return 0;
+	return extractType(uplimit);
 }
 
-Container* Container::dlimit() const
+Object* Container::dlimit() const
 {
-	for(QList<Object*>::const_iterator it=m_params.begin(); it!=m_params.end(); ++it) {
-		Container *c = (Container*) (*it);
-		if(c->type()==Object::container && c->containerType()==Container::downlimit && c->m_params[0]->type()==Object::value)
-			return (Container*) c->m_params[0];
-	}
-	return 0;
+	return extractType(downlimit);
 }
 
 bool Container::hasVars() const
@@ -178,7 +174,6 @@ bool Container::hasVars() const
 bool Container::operator==(const Container& c) const
 {
 	bool eq=c.m_params.count()==m_params.count();
-	QList<Object*>::const_iterator it = c.m_params.begin();
 	
 	for(int i=0; eq && i<m_params.count(); ++i) {
 		Object *o=m_params[i], *o1=c.m_params[i];
@@ -187,26 +182,34 @@ bool Container::operator==(const Container& c) const
 	return eq;
 }
 
-bool Container::equalTree(Object const* o1, Object const * o2)
+bool Container::equalTree(const Object * o1, const Object * o2)
 {
 	Q_ASSERT(o1 && o2);
 	if(o1==o2)
 		return true;
-	bool eq= o1->type()==o2->type();
+	else if(o1->type()!=o2->type())
+		return false;
+	
+	bool eq;
 	switch(o2->type()) {
 		case Object::variable:
-			eq = eq && Ci(o2)==Ci(o1);
+			eq = *static_cast<const Ci*>(o1)==*static_cast<const Ci*>(o2);
 			break;
 		case Object::value:
-			eq = eq && Cn(o2)==Cn(o1);
+			eq = *static_cast<const Cn*>(o1)==*static_cast<const Cn*>(o2);
 			break;
 		case Object::container:
-			eq = eq && Container(o2)==Container(o1);
+			eq = *static_cast<const Container*>(o1)==*static_cast<const Container*>(o2);
 			break;
 		case Object::oper:
-			eq = eq && Operator(o2)==Operator(o1);
+			eq = *static_cast<const Operator*>(o1)==*static_cast<const Operator*>(o2);
 			break;
-		default:
+		case Object::vector:
+			eq = *static_cast<const Vector*>(o1)==*static_cast<const Vector*>(o2);
+			break;
+		case Object::none:
+			eq=false;
+			Q_ASSERT(false && "Should not get here");
 			break;
 	}
 	return eq;
@@ -310,7 +313,7 @@ Object* Container::monomialVar(const Container& c) //FIXME: Must improve these v
 
 void objectWalker(const Object* root, int ind)
 {
-	Container *c; Cn *num; Operator *op; Ci *var;
+	Container *c; Cn *num; Ci *var;
 	QString s;
 	
 	if(ind>100) return;
@@ -326,26 +329,32 @@ void objectWalker(const Object* root, int ind)
 		case Object::container:
 			Q_ASSERT(dynamic_cast<const Container*>(root));
 			c= (Container*) root;
-			qDebug() << qPrintable(s) << "| cont: " << c->tagName() << "=";// << c->toString();
-			for(int i=0; i<c->m_params.count(); i++)
-				objectWalker(c->m_params[i], ind+1);
+			qDebug() << qPrintable(s) << "| cont: " << c->tagName();// << "=" << c->toString();
+			for(Container::const_iterator it=c->m_params.constBegin(); it<c->m_params.constEnd(); ++it)
+				objectWalker(*it, ind+1);
 			
 			break;
 		case Object::value:
 			Q_ASSERT(dynamic_cast<const Cn*>(root));
 			num= (Cn*) root;
-			qDebug() << qPrintable(s) << "| num: " << num->value();
+			qDebug() << qPrintable(s) << "| num: " << num->value() << num->format();
 			break;
 		case Object::oper:
 			Q_ASSERT(dynamic_cast<const Operator*>(root));
-			op= (Operator*) root;
-			qDebug() << qPrintable(s) << "| operator: " << op->toString();
+			qDebug() << qPrintable(s) << "| operator: " << root->toString();
 			break;
 		case Object::variable:
 			Q_ASSERT(dynamic_cast<const Ci*>(root));
 			var = (Ci*) root;
 			qDebug() << qPrintable(s) << "| variable: " << var->name() << "Func:" << var->isFunction();
 			break;
+		case Object::vector: {
+			const Vector* v;
+			Q_ASSERT(v=dynamic_cast<const Vector*>(root));
+			qDebug() << qPrintable(s) << "| vector: " << v->size();
+			for(Vector::const_iterator it=v->constBegin(); it!=v->constEnd(); ++it)
+				objectWalker(*it, ind+1);
+		}	break;
 		default:
 			qDebug() << qPrintable(s) << "| dunno: " << (int) root->type() << root;
 			break;
@@ -354,37 +363,13 @@ void objectWalker(const Object* root, int ind)
 		qDebug(";");
 }
 
-void print_dom(const QDomNode& in, int ind)
-{
-	QString a;
-
-	if(ind >100){
-		qDebug("...");
-		return;
-	}
-	
-	for(int i=0; i<ind; i++)
-		a.append("______|");
-
-	if(in.hasChildNodes())
-		qDebug("%s%s(%s) -- %d", qPrintable(a), qPrintable(in.toElement().tagName()), qPrintable(in.toElement().text()), in.childNodes().length());
-	else
-		qDebug("%s%s", qPrintable(a), qPrintable(in.toElement().tagName()));
-
-	for(unsigned int i=0 ; i<in.childNodes().length(); i++){
-		if(in.childNodes().item(i).isElement())
-			print_dom(in.childNodes().item(i), ind+1);
-	}
-}
-
-
 bool Container::isNumber() const
 {
 	return m_cont_type==apply || m_cont_type==math || m_cont_type==lambda || m_cont_type==declare ||
-		m_cont_type==piecewise || m_cont_type==piece || m_cont_type==vector || m_cont_type==otherwise;
+		m_cont_type==piecewise || m_cont_type==piece || m_cont_type==otherwise;
 }
 
-QList<Object *>::iterator Container::firstValue()
+Container::iterator Container::firstValue()
 {
 	QList<Object *>::iterator it(m_params.begin()), itEnd(m_params.end());
 	bool found=false;
@@ -392,22 +377,25 @@ QList<Object *>::iterator Container::firstValue()
 		switch((*it)->type()) {
 			case Object::value:
 			case Object::variable:
+			case Object::vector:
 				found=true;
 				break;
 			case Object::container:
 				if(((Container*) *it)->isNumber())
 					found=true;
 				break;
-			default:
+			case Object::oper:
+			case Object::none:
 				break;
 		}
 		if(found)
 			break;
 	}
+	
 	return it;
 }
 
-QList<Object *>::const_iterator Container::firstValue() const
+Container::const_iterator Container::firstValue() const
 {
 	QList<Object *>::const_iterator it(m_params.constBegin()), itEnd(m_params.constEnd());
 	for(; it!=itEnd; ++it) {
@@ -415,6 +403,7 @@ QList<Object *>::const_iterator Container::firstValue() const
 		
 		switch((*it)->type()) {
 			case Object::value:
+			case Object::vector:
 			case Object::variable:
 				found=true;
 				break;
@@ -422,7 +411,8 @@ QList<Object *>::const_iterator Container::firstValue() const
 				if(((Container*) *it)->isNumber())
 					found=true;
 				break;
-			default:
+			case Object::oper:
+			case Object::none:
 				break;
 		}
 		if(found)
@@ -439,48 +429,54 @@ bool Container::isUnary() const
 
 bool Container::isCorrect() const
 {
-	return m_correct && m_type==Object::container && m_cont_type!=none/* && !isEmpty()*/;
+	bool ret=m_type==Object::container && m_cont_type!=none;
+	if(m_cont_type==Container::apply) {
+		Operator o=firstOperator();
+		ret &= o.nparams()<0 || countValues()==o.nparams();
+	}
+	return ret;
 }
 
 QString Container::tagName() const
 {
-	QString tag;
-	switch(m_cont_type) {
-		case declare:
-			tag="declare";
-			break;
-		case lambda:
-			tag="lambda";
-			break;
-		case math:
-			tag="math";
-			break;
-		case apply:
-			tag="apply";
-			break;
-		case uplimit:
-			tag="uplimit";
-			break;
-		case downlimit:
-			tag="downlimit";
-			break;
-		case bvar:
-			tag="bvar";
-			break;
-		case piece:
-			tag="piece";
-			break;
-		case piecewise:
-			tag="piecewise";
-			break;
-		case otherwise:
-			tag="otherwise";
-			break;
-		case vector:
-			tag="vector";
-			break;
-		case none:
-			break;
+	return QString(m_typeStr[m_cont_type]);
+}
+
+bool Container::matches(const Object* exp, QMap<QString, const Object*>* found) const
+{
+	if(Object::container!=exp->type())
+		return false;
+	const Container* c=(const Container*) exp;
+	if(m_params.count()!=c->m_params.count())
+		return false;
+	
+	bool matching=true;
+	Container::const_iterator it, it2, itEnd=m_params.constEnd();
+	for(it=m_params.constBegin(), it2=c->m_params.constBegin(); matching && it!=itEnd; ++it, ++it2)
+	{
+		matching &= (*it)->matches(*it2, found);
 	}
-	return tag;
+	return matching;
+}
+
+int Container::countValues() const
+{
+	Container::const_iterator it=firstValue(), itEnd=m_params.constEnd();
+	int count=0;
+	
+	for(; it!=itEnd; ++it)
+	{
+		count++;
+	}
+	return count;
+}
+
+Object* Container::extractType(Container::ContainerType t) const
+{
+	for(Container::const_iterator it=m_params.begin(); it!=m_params.end(); ++it) {
+		Container *c = (Container*) (*it);
+		if(c->isContainer() && c->containerType()==t)
+			return c->m_params.first();
+	}
+	return 0;
 }
