@@ -30,6 +30,7 @@
 #include "expressionedit.h"
 
 class Graph2D;
+class Variables;
 
 /**
  *	The color combo shows a different colors list.
@@ -103,6 +104,11 @@ public:
 	/** Retrieves a name for the function. (Not used YET) */
 	QString name() const { return m_name->text(); }
 	
+	/** Sets the variables class to be used with the graph functions*/
+	void setVariables(Variables* v) { m_vars=v; }
+	
+	Variables* variables() const { return m_vars; }
+	
 public slots:
 	/** Clears the dialog. */
 	void clear();
@@ -119,6 +125,7 @@ private:
 	Graph2D *m_graph;
 	KColorCombo *m_color;
 	FunctionsModel *m_funcsModel;
+	Variables* m_vars;
 	
 	bool m_correct;
 	bool m_modmode;
