@@ -55,10 +55,10 @@ void RSDialog::filter()
 	//if the RS sentence starts or ends with a - invalidate it.
 	//It is probably an user error
 	if(
-		ui.r_le->text().startsWith("-") ||
-		ui.r_le->text().endsWith("-") || 
-		ui.s_le->text().startsWith("-") || 
-		ui.s_le->text().endsWith("-") 
+		ui.r_le->text().startsWith('-') ||
+		ui.r_le->text().endsWith('-') || 
+		ui.s_le->text().startsWith('-') || 
+		ui.s_le->text().endsWith('-') 
 	)
 	{
 		invalidPhaseString();
@@ -71,7 +71,7 @@ void RSDialog::filter()
     //for now only separation by a - is allowed
     if (!ui.r_le->text().isEmpty() )
     {
-        QStringList rSplit = ui.r_le->text().split( "-" );
+        const QStringList rSplit = ui.r_le->text().split( '-' );
         foreach( const QString &st, rSplit )
             r << st.toInt();
     }
@@ -79,7 +79,7 @@ void RSDialog::filter()
     //for now only separation by a - is allowed
     if (!ui.s_le->text().isEmpty() )
     {
-        QStringList sSplit = ui.s_le->text().split( "-" );
+        const QStringList sSplit = ui.s_le->text().split( '-' );
         foreach( const QString &st, sSplit )
             s << st.toInt();
     }
@@ -121,8 +121,8 @@ QString RSDialog::rphrase( int number )
 {
 	QString p;
 	
-	QMap<int, QString>::const_iterator i = rphrases_map.begin();
-	while ( i != rphrases_map.end() )
+	QMap<int, QString>::const_iterator i = rphrases_map.constBegin();
+	while ( i != rphrases_map.constEnd() )
 	{
 		if ( i.key() == number )
 			return i.value();
@@ -137,8 +137,8 @@ QString RSDialog::sphrase( int number )
 {
 	QString p;
 	
-	QMap<int, QString>::const_iterator i = sphrases_map.begin();
-	while ( i != sphrases_map.end() )
+	QMap<int, QString>::const_iterator i = sphrases_map.constBegin();
+	while ( i != sphrases_map.constEnd() )
 	{
 		if ( i.key() == number )
 			return i.value();
