@@ -20,12 +20,14 @@
 #include <QtDBus/QtDBus>
 #include <kxmlguiwindow.h>
 
+#include <config-kstars.h>
 
 #include "tools/observinglist.h"
 
 // forward declaration is enough. We only need pointers
 class QPalette;
 class KActionMenu;
+class KLed;
 
 class dms;
 class KStarsData;
@@ -42,43 +44,73 @@ class imagesequence;
 class AltVsTime;
 class LCGenerator;
 class WUTDialog;
+class SkyCalendar;
 class ScriptBuilder;
 class PlanetViewer;
 class JMoonTool;
 class ImageViewer;
+class FlagManager;
 
 class OpsCatalog;
 class OpsGuides;
 class OpsSolarSystem;
 class OpsColors;
 class OpsAdvanced;
+class OpsINDI;
+#ifdef HAVE_XPLANET
+class OpsXplanet;
+#endif
 
 /**
-	*@class KStars
-	*@short This is the main window for KStars.
-	*In addition to the GUI elements, the class contains the program clock,
-	*KStarsData, and SkyMap objects.  It also contains functions for the DCOP interface.
-	*@author Jason Harris
-	*@version 1.0
-	*/
+ *@class KStars
+ *@short This is the main window for KStars.
+ *In addition to the GUI elements, the class contains the program clock,
+ *KStarsData, and SkyMap objects.  It also contains functions for the D-Bus interface.
+ *@author Jason Harris
+ *@version 1.0
+ */
+
+// KStars is now a singleton class. Use KStars::createInstance() to
+// create an instance and KStars::Instance() to get a pointer to the
+// instance
+// asimha, 9th May 2009
 
 class KStars : public KXmlGuiWindow
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kstars")
 
-public:
+private:
     /**
-    	*@short Constructor.
-    	*@param doSplash should the splash panel be displayed during
-    	*initialization.
-    	*@param startClockRunning should the clock be running on startup?
-    	*@param startDateString date (in string representation) to start running from.
-    	*
-    	* @todo Refer to documentation on date format.
-    	*/
+     *@short Constructor.
+     *@param doSplash should the splash panel be displayed during
+     *initialization.
+     *@param startClockRunning should the clock be running on startup?
+     *@param startDateString date (in string representation) to start running from.
+     *
+     * @todo Refer to documentation on date format.
+     */
     explicit KStars( bool doSplash, bool startClockRunning = true, const QString &startDateString = QString() );
 
+    static KStars *pinstance; // Pointer to an instance of KStars
+
+public:
+
+    /**
+     *@short Create an instance of this class. Destroy any previous instance
+     *@param doSplash
+     *@param clockrunning
+     *@param startDateString
+     *@note See KStars::KStars for details on parameters
+     *@return a pointer to the instance
+     */
+    static KStars *createInstance( bool doSplash, bool clockrunning = true, const QString &startDateString = QString() );
+
+    /**
+     *@return a pointer to the instance of this class
+     */
+    inline static KStars *Instance() { return pinstance; }
+
     /**Destructor.  Synchs config file.  Deletes objects.
     	*/
     ~KStars();
@@ -108,13 +140,15 @@ public:
     	*/
     InfoBoxes* infoBoxes();
 
+    inline KLed* diskLED() { return m_DiskLED; }
+
     /**@return pointer to the INDI driver
     	*/
-    INDIDriver* getINDIDriver() { return indidriver; }
+    INDIDriver* indiDriver() { return indidriver; }
 
     /**@return pointer to the INDI menu
     	*/
-    INDIMenu* getINDIMenu() { return indimenu; }
+    INDIMenu* indiMenu() { return indimenu; }
 
     /** Establish the INDI system. No GUI
     	*/
@@ -419,11 +453,24 @@ public Q_SLOTS:
     	*/
     void slotApplyToolbarConfig();
 
+    /**
+    	* Zoom in by a given factor
+        *
+    	*/
+    void zoomIn( const double factor );
+
+    /**
+    	* Zoom out by a given factor
+        *
+    	*/
+    void zoomOut( const double factor );
+
     /**
     	*action slot: Zoom in one step
     	*/
     void slotZoomIn();
 
+
     /**
     	*action slot: Zoom out one step
     	*/
@@ -514,6 +561,11 @@ private slots:
      */
     void slotWUT();
 
+    /**
+     * action slot: open Sky Calendar tool
+     */
+    void slotCalendar();
+
     /**
      * action slot: open the glossary
      */
@@ -534,6 +586,11 @@ private slots:
      */
     void slotJMoonTool();
 
+    /**
+     * action slot: open Flag Manager
+     */
+    void slotFlagManager();
+
     /**
      * action slot: open Telescope wizard
      */
@@ -559,11 +616,6 @@ private slots:
     */
     void slotINDIPanel();
 
-    /**
-     * action slot: open INDI configuration dialog
-     */
-    void slotINDIConf();
-
     /**
     	*action slot: open dialog for setting the view options
     	*/
@@ -665,6 +717,8 @@ private:
     	*/
     void buildGUI();
 
+    void reportZoom();
+
     KStarsData *kstarsData;
     KStarsSplash *splash;
     SkyMap *skymap;
@@ -680,10 +734,12 @@ private:
     ObservingList *obsList;
     AltVsTime *avt;
     WUTDialog *wut;
+    SkyCalendar *skycal;
     ScriptBuilder *sb;
     PlanetViewer *pv;
     JMoonTool *jmt;
     QList<ImageViewer*> m_ImageViewerList;
+    FlagManager *fm;
 
     INDIMenu *indimenu;
     INDIDriver *indidriver;
@@ -703,6 +759,12 @@ private:
     OpsSolarSystem *opsolsys;
     OpsColors *opcolors;
     OpsAdvanced *opadvanced;
+    OpsINDI	*opsindi;
+#ifdef HAVE_XPLANET
+    OpsXplanet  *opsxplanet;
+#endif
+
+    KLed *m_DiskLED;
 };
 
 #endif
