@@ -40,8 +40,8 @@
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "skymap.h"
-#include "skyobject.h"
-#include "ksplanetbase.h"
+#include "skyobjects/skyobject.h"
+#include "skyobjects/ksplanetbase.h"
 #include "infoboxes.h"
 #include "simclock.h"
 #include "Options.h"
@@ -50,12 +50,12 @@
 #include <config-kstars.h>
 
 #ifdef HAVE_INDI_H
-#include "indidriver.h"
-#include "indimenu.h"
-#include "indielement.h"
-#include "indidevice.h"
-#include "indiproperty.h"
-#include "devicemanager.h"
+#include "indi/indidriver.h"
+#include "indi/indimenu.h"
+#include "indi/indielement.h"
+#include "indi/indidevice.h"
+#include "indi/indiproperty.h"
+#include "indi/devicemanager.h"
 #endif
 
 void KStars::setRaDec( double ra, double dec ) {
@@ -292,7 +292,8 @@ void KStars::changeViewOption( const QString &op, const QString &val ) {
 
     //[View]
     if ( op == "FOVName"                ) Options::setFOVName(         val );
-    if ( op == "FOVSize"         && dOk ) Options::setFOVSize( (float)dVal );
+    if ( op == "FOVSizeX"         && dOk ) Options::setFOVSizeX( (float)dVal );
+    if ( op == "FOVSizeY"         && dOk ) Options::setFOVSizeY( (float)dVal );
     if ( op == "FOVShape"        && nOk ) Options::setFOVShape(       nVal );
     if ( op == "FOVColor"               ) Options::setFOVColor(        val );
     if ( op == "ShowStars"       && bOk ) Options::setShowStars(      bVal );
@@ -428,7 +429,7 @@ void KStars::exportImage( const QString &url, int w, int h ) {
 
     if ( fileURL.isValid() ) {
         if ( fileURL.isLocalFile() ) {
-            fname = fileURL.path();
+            fname = fileURL.toLocalFile();
         } else {
             fname = tmpfile.fileName();
         }
