@@ -31,20 +31,20 @@
 
 #include "ksconjunct.h"
 #include "geolocation.h"
-#include "locationdialog.h"
+#include "dialogs/locationdialog.h"
 #include "dms.h"
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "ksnumbers.h"
-#include "kssun.h"
-#include "ksplanet.h"
-#include "ksplanetbase.h"
-#include "ksmoon.h"
-#include "kspluto.h"
+#include "skyobjects/kssun.h"
+#include "skyobjects/ksplanet.h"
+#include "skyobjects/ksplanetbase.h"
+#include "skyobjects/ksmoon.h"
+#include "skyobjects/kspluto.h"
 #include "widgets/dmsbox.h"
-#include "finddialog.h"
-#include "kscomet.h"
-#include "ksasteroid.h"
+#include "dialogs/finddialog.h"
+#include "skyobjects/kscomet.h"
+#include "skyobjects/ksasteroid.h"
 #include "skymap.h"
 #include "infoboxes.h"
 
@@ -88,6 +88,10 @@ ConjunctionsTool::ConjunctionsTool(QWidget *parentSplit)
         Obj2ComboBox->insertItem( i, pNames[i] );
     }
 
+    // Initialize the Maximum Separation box to 1 degree
+    maxSeparationBox->setDegType( true );
+    maxSeparationBox->setDMS( "01 00 00.0" );
+
     // signals and slots connections
     connect(LocationButton, SIGNAL(clicked()), this, SLOT(slotLocation()));
     connect(Obj1FindButton, SIGNAL(clicked()), this, SLOT(slotFindObject()));
@@ -122,35 +126,17 @@ void ConjunctionsTool::slotGoto() {
 }
 
 void ConjunctionsTool::slotFindObject() {
-    FindDialog fd( (KStars*) topLevelWidget()->parent() );
-    if ( fd.exec() == QDialog::Accepted ) {
+    QPointer<FindDialog> fd = new FindDialog( (KStars*) topLevelWidget()->parent() );
+    if ( fd->exec() == QDialog::Accepted ) {
         if( Object1 )
             delete Object1;
-        if( !fd.selectedObject() )
+        if( !fd->selectedObject() )
             return;
-        if( !fd.selectedObject()->isSolarSystem() ) {
-            Object1 = new SkyObject( *fd.selectedObject() );
-        }
-        else {
-            switch( fd.selectedObject()->type() ) {
-            case 9: {
-                Object1 =  new KSComet( (KSComet &) *fd.selectedObject() );
-                break;
-            }
-            case 10: {
-                Object1 =  new KSAsteroid( (KSAsteroid &) *fd.selectedObject() );
-                break;
-            }
-            case 2: 
-            default: {
-                Object1 = KSPlanetBase::createPlanet( pNames.key( fd.selectedObject()->name() ) ); // TODO: Fix i18n issues.
-                break;
-            }
-            }
-        }
+        Object1 = fd->selectedObject()->clone();
         if( Object1 )
             Obj1FindButton->setText( Object1->name() );
     }
+    delete fd;
 }
 
 void ConjunctionsTool::slotLocation()
@@ -170,12 +156,17 @@ void ConjunctionsTool::slotCompute (void)
     KStarsDateTime dtStop = stopDate -> dateTime();
     long double startJD = dtStart.djd();
     long double stopJD = dtStop.djd();
-    dms maxSeparation(1.0); // TODO: Make maxSeparation user-specifiable
-    // TODO: Get geoPlace from user.
-    //    dms LST( geoPlace->GSTtoLST( dt.gst() ) );
-
+    bool opposition = false;
+    if(Opposition->currentIndex()) opposition = true;
+    
+    dms maxSeparation( 0.0 );
+    bool ok;
+    maxSeparation = maxSeparationBox->createDms( true, &ok );
+    if( !ok ) {
+        KMessageBox::sorry( 0, i18n("Maximum separation entered is not a valid angle. Use the What's this help feature for information on how to enter a valid angle") );
+        return;
+    }
     if( !Object1 ) {
-        // TODO: Display some error message
         KMessageBox::sorry( 0, i18n("Please select an object to check conjunctions with, by clicking on the \'Find Object\' button.") );
         return;
     }
@@ -186,10 +177,11 @@ void ConjunctionsTool::slotCompute (void)
     }
     QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
     KSConjunct ksc;
+    ksc.setGeoLocation( geoPlace );
     ComputeStack->setCurrentIndex( 1 );
     connect( &ksc, SIGNAL(madeProgress(int)), this, SLOT(showProgress(int)) );
 
-    showConjunctions( ksc.findClosestApproach(*Object1, *Object2, startJD, stopJD, maxSeparation) );
+    showConjunctions( ksc.findClosestApproach(*Object1, *Object2, startJD, stopJD, maxSeparation, opposition) );
 
     ComputeStack->setCurrentIndex( 0 );
     QApplication::restoreOverrideCursor();
@@ -215,11 +207,15 @@ void ConjunctionsTool::showConjunctions(const QMap<long double, dms> &conjunctio
 
     for(it = conjunctionlist.constBegin(); it != conjunctionlist.constEnd(); ++it) {
         dt.setDJD( it.key() );
-        OutputView -> addItem( i18n("Conjunction on %1 UT: Separation is %2", 
-                                    KGlobal::locale()->formatDateTime( dt, KLocale::LongDate ), 
-                                    it.value().toDMSString()) );
+        if(!Opposition->currentIndex())
+		OutputView -> addItem( i18n("Conjunction on %1 UT: Separation is %2", 
+                	                    KGlobal::locale()->formatDateTime( dt, KLocale::LongDate ), 
+                        	            it.value().toDMSString()) );
+	else
+		OutputView -> addItem( i18n("Opposition on %1 UT: Separation is %2", 
+        	                            KGlobal::locale()->formatDateTime( dt, KLocale::LongDate ), 
+                	                    it.value().toDMSString()) );
         outputJDList.insert( i, it.key() );
         ++i;
     }
 }
-
