@@ -24,13 +24,13 @@
 
 #include "ksnumbers.h"
 #include "dms.h"
-#include "skypoint.h"
+#include "skyobjects/skypoint.h"
 #include "geolocation.h"
 #include "kstars.h"
 #include "kstarsdatetime.h"
 #include "widgets/dmsbox.h"
-#include "locationdialog.h"
-#include "finddialog.h"
+#include "dialogs/locationdialog.h"
+#include "dialogs/finddialog.h"
 
 modCalcVlsr::modCalcVlsr(QWidget *parentSplit) : QFrame(parentSplit), velocityFlag(0)
 {
@@ -80,12 +80,13 @@ void modCalcVlsr::slotNow()
 }
 
 void modCalcVlsr::slotFindObject() {
-    FindDialog fd( (KStars*)topLevelWidget()->parent() );
-    if ( fd.exec() == QDialog::Accepted ) {
-        SkyObject *o = fd.selectedObject();
+    QPointer<FindDialog> fd = new FindDialog( (KStars*)topLevelWidget()->parent() );
+    if ( fd->exec() == QDialog::Accepted ) {
+        SkyObject *o = fd->selectedObject();
         RA->showInHours( o->ra0() );
         Dec->showInDegrees( o->dec0() );
     }
+    delete fd;
 }
 
 void modCalcVlsr::slotLocation() {
@@ -169,7 +170,7 @@ void modCalcVlsr::slotCompute()
         }
 
     default: //oops
-        kDebug() << i18n("Error: I do not know which velocity to use for input.");
+        kDebug() << i18n("Error: do not know which velocity to use for input.");
         break;
     }
 }
@@ -261,7 +262,7 @@ void modCalcVlsr::slotOutputFile() {
 void modCalcVlsr::slotRunBatch() {
     QString inputFileName;
 
-    inputFileName = InputFileBoxBatch->url().path();
+    inputFileName = InputFileBoxBatch->url().toLocalFile();
 
     // We open the input file and read its content
 
@@ -294,13 +295,13 @@ void modCalcVlsr::processLines( QTextStream &istream ) {
 
     //	QTextStream istream(&fIn);
     QString outputFileName;
-    outputFileName = OutputFileBoxBatch->url().path();
+    outputFileName = OutputFileBoxBatch->url().toLocalFile();
     QFile fOut( outputFileName );
     fOut.open(QIODevice::WriteOnly);
     QTextStream ostream(&fOut);
 
     QString line;
-    QString space = " ";
+    QChar space = ' ';
     int i = 0;
     long double jd0;
     SkyPoint spB;
