@@ -514,7 +514,7 @@ bool KTouchStatisticsData::writeUserStats(QWidget * window, const KUrl& url,
     QString tmpFile;
     KTemporaryFile *temp=0;
     if (url.isLocalFile())
-        tmpFile=url.path();         // for local files the path is sufficient
+        tmpFile=url.toLocalFile();         // for local files the path is sufficient
     else {
         temp=new KTemporaryFile;         // for remote files create a temporary file first
         temp->open();
