@@ -1,5 +1,5 @@
 /* This file is part of KWordQuiz
-  Copyright (C) 2003-2008 Peter Hedlund <peter.hedlund@kdemail.net>
+  Copyright (C) 2003-2009 Peter Hedlund <peter.hedlund@kdemail.net>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 
 #include <KActionCollection>
 
-class KWQQuiz;
-class WQScore;
+class KWQQuizModel;
 
 /**
 @author Peter Hedlund
@@ -35,7 +34,7 @@ Q_OBJECT
 public:
     QAView(QWidget *parent, KActionCollection * actionCollection);
 
-    void setQuiz(KWQQuiz *quiz);
+    void setQuiz(KWQQuizModel *quiz);
     void init();
 
 public slots:
@@ -47,17 +46,12 @@ public slots:
     void slotSpecChar(const QChar &);
 
 private:
-    KWQQuiz *m_quiz;
-    WQScore *m_score;
+    KWQQuizModel *m_quiz;
     KActionCollection *m_actionCollection;
 
-    int m_question;
-    int m_error;
-
     bool m_hintUsed;
 
-    void updateScore();
-    void showQuestion(int i);
+    void showQuestion();
 };
 
 #endif
