@@ -27,6 +27,7 @@
 
 #include "keduvocdocument.h"
 #include "keduvoclesson.h"
+#include "keduvocleitnerbox.h"
 #include "keduvocwordtype.h"
 #include "kvtml2defs.h"
 #include "keduvockvtmlreader.h"
@@ -144,9 +145,19 @@ bool KEduVocKvtml2Reader::readGroups( QDomElement &domElementParent )
 {
     bool result = false;
 
+    QDomElement groupElement = domElementParent.firstChildElement( KVTML_IDENTIFIERS );
+
     QDomElement currentElement;
 
-    QDomElement groupElement = domElementParent.firstChildElement( KVTML_IDENTIFIERS );
+    // ensure backwards compatibility - in kde 4.1 and earlier tenses were direct properties of the document class.
+    // now they are moved into the individual identifiers
+    QStringList tensesCompability;
+    groupElement = groupElement.firstChildElement( KVTML_TENSES );
+    if ( !groupElement.isNull() ) {
+        tensesCompability = readTenses( groupElement );
+    }
+
+    groupElement = domElementParent.firstChildElement( KVTML_IDENTIFIERS );
     if ( !groupElement.isNull() ) {
         QDomNodeList entryList = groupElement.elementsByTagName( KVTML_IDENTIFIER );
         if ( entryList.length() <= 0 ) {
@@ -158,17 +169,16 @@ bool KEduVocKvtml2Reader::readGroups( QDomElement &domElementParent )
             currentElement = entryList.item( i ).toElement();
             if ( currentElement.parentNode() == groupElement ) {
                 result = readIdentifier( currentElement );
-                if ( !result )
+                if ( !result ) {
                     return false;
+                }
+                if (!tensesCompability.isEmpty()) {
+                    m_doc->identifier(i).setTenseList(tensesCompability);
+                }
             }
         }
     }
 
-    groupElement = domElementParent.firstChildElement( KVTML_TENSES );
-    if ( !groupElement.isNull() ) {
-        readTenses( groupElement );
-    }
-
     groupElement = domElementParent.firstChildElement( KVTML_ENTRIES );
     if ( !groupElement.isNull() ) {
         QDomNodeList entryList = groupElement.elementsByTagName( KVTML_ENTRY );
@@ -189,6 +199,11 @@ bool KEduVocKvtml2Reader::readGroups( QDomElement &domElementParent )
         readChildWordTypes( m_doc->wordTypeContainer(), groupElement );
     }
 
+    groupElement = domElementParent.firstChildElement( KVTML_LEITNERBOXES );
+    if ( !groupElement.isNull() ) {
+        readLeitner( m_doc->leitnerContainer(), groupElement );
+    }
+
     groupElement = domElementParent.firstChildElement( KVTML_LESSONS );
     if ( !groupElement.isNull() ) {
         readChildLessons(m_doc->lesson(), groupElement);
@@ -242,11 +257,6 @@ bool KEduVocKvtml2Reader::readIdentifier( QDomElement &identifierElement )
         // TODO: do something with the type
     }
 
-    currentElement = identifierElement.firstChildElement( KVTML_SIZEHINT );
-    if ( !currentElement.isNull() ) {
-        // TODO: do something with the sizehint
-    }
-
     // read sub-parts
     currentElement = identifierElement.firstChildElement( KVTML_ARTICLE );
     if ( !currentElement.isNull() ) {
@@ -259,6 +269,12 @@ bool KEduVocKvtml2Reader::readIdentifier( QDomElement &identifierElement )
         readPersonalPronoun( currentElement, personalPronoun );
         m_doc->identifier(id).setPersonalPronouns( personalPronoun );
     }
+
+    QStringList tenses = readTenses(identifierElement);
+kDebug() << tenses;
+
+    m_doc->identifier(id).setTenseList(tenses);
+
     return result;
 }
 
@@ -287,14 +303,8 @@ bool KEduVocKvtml2Reader::readEntry( QDomElement &entryElement )
         }
     }
 
-
     // read translation children
     QDomNodeList translationList = entryElement.elementsByTagName( KVTML_TRANSLATION );
-    if ( translationList.length() <= 0 ) {
-        delete expr;
-        m_errorMessage = i18n( "no translations found" );
-        return false; // at least one translation is required
-    }
 
     for ( int i = 0; i < translationList.count(); ++i ) {
         currentElement = translationList.item( i ).toElement();
@@ -305,6 +315,13 @@ bool KEduVocKvtml2Reader::readEntry( QDomElement &entryElement )
         }
     }
 
+    if ( expr->translationIndices().size() == 0 ) {
+        kDebug() << "Found entry with no words in it." << id;
+        expr->setTranslation(0, QString());
+    }
+
+    Q_ASSERT(expr);
+
     // TODO: probably should insert at id position with a check to see if it exists
     // may be useful for detecting corrupt documents
     m_allEntries[id] = expr;
@@ -363,7 +380,6 @@ bool KEduVocKvtml2Reader::readChildLessons( KEduVocLesson* parentLesson, QDomEle
     return true;
 }
 
-
 bool KEduVocKvtml2Reader::readLesson( KEduVocLesson* parentLesson, QDomElement &lessonElement )
 {
     //<name>Lesson name</name>
@@ -383,14 +399,15 @@ bool KEduVocKvtml2Reader::readLesson( KEduVocLesson* parentLesson, QDomElement &
         bool result = false;
         int entryId = currentElement.attribute( KVTML_ID ).toInt( &result );
         if(result) {
-            lesson->appendEntry( m_allEntries[entryId] );
+            if (m_allEntries[entryId]) {
+                lesson->appendEntry( m_allEntries[entryId] );
+            }
         }
         currentElement = currentElement.nextSiblingElement( KVTML_ENTRY );
     }
     return true;
 }
 
-
 bool KEduVocKvtml2Reader::readSynonymsAntonymsFalseFriends( QDomElement &rootElement )
 {
     QDomElement pairElement;
@@ -466,19 +483,30 @@ bool KEduVocKvtml2Reader::readArticle( QDomElement &articleElement, int identifi
  </article>
 */
 {
-    // singular
-    for ( KEduVocArticle::ArticleNumber num = KEduVocArticle::Singular; num <= KEduVocArticle::Plural; num = KEduVocArticle::ArticleNumber(num+1) ) {
+    QMap<int, KEduVocWordFlag::Flags> numbers;
+    numbers[0] = KEduVocWordFlag::Singular;
+    numbers[1] = KEduVocWordFlag::Dual;
+    numbers[2] = KEduVocWordFlag::Plural;
+    QMap<int, KEduVocWordFlag::Flags> genders;
+    genders[0] = KEduVocWordFlag::Masculine;
+    genders[1] = KEduVocWordFlag::Feminine;
+    genders[2] = KEduVocWordFlag::Neuter;
+    QMap<int, KEduVocWordFlag::Flags> defs;
+    defs[0] = KEduVocWordFlag::Definite;
+    defs[1] = KEduVocWordFlag::Indefinite;
+
+    for ( int num = 0; num <= 2; ++num) {
         QDomElement numberElement = articleElement.firstChildElement( KVTML_GRAMMATICAL_NUMBER[num] );
         if (!numberElement.isNull()) {
             // definite
-            for ( KEduVocArticle::ArticleDefiniteness def = KEduVocArticle::Definite; def <= KEduVocArticle::Indefinite; def = KEduVocArticle::ArticleDefiniteness(def+1) ) {
+            for ( int def = 0; def <= 1; ++def ) {
                 QDomElement defElement = numberElement.firstChildElement( KVTML_GRAMMATICAL_DEFINITENESS[def] );
                 if (!defElement.isNull()) {
                     // male
-                    for ( KEduVocArticle::ArticleGender gen = KEduVocArticle::Masculine; gen <= KEduVocArticle::Neutral; gen = KEduVocArticle::ArticleGender(gen+1) ) {
+                    for ( int gen = 0; gen <= 2; ++gen ) {
                         QDomElement genderElement = defElement.firstChildElement( KVTML_GRAMMATICAL_GENDER[gen] );
                         if (!genderElement.isNull()) {
-                            m_doc->identifier(identifierNum).article().setArticle( genderElement.text(), KEduVocArticle::indexOf(num, def, gen) );
+                            m_doc->identifier(identifierNum).article().setArticle( genderElement.text(), numbers[num] | defs[def] | genders[gen]);
                         }
                     }
                 }
@@ -500,6 +528,35 @@ bool KEduVocKvtml2Reader::readChildWordTypes(KEduVocWordType* parentContainer, Q
     return true;
 }
 
+bool KEduVocKvtml2Reader::readLeitner( KEduVocLeitnerBox* parentContainer, QDomElement &leitnerParentElement )
+{
+    QDomElement leitnerElement = leitnerParentElement.firstChildElement( KVTML_CONTAINER );
+    while ( !leitnerElement.isNull() ) {
+        QString name = leitnerElement.firstChildElement( KVTML_NAME ).text();
+
+        KEduVocLeitnerBox * leitner = new KEduVocLeitnerBox(name, parentContainer);
+        parentContainer->appendChildContainer(leitner);
+        // for leitner we only allow a flat list, no sub boxes.
+
+        // read entries
+        QDomElement entryElement = leitnerElement.firstChildElement( KVTML_ENTRY );
+        while ( !entryElement.isNull() ) {
+            // read <entry id="123"></entryid>
+            int entryId = entryElement.attribute( KVTML_ID ).toInt();
+            QDomElement translationElement = entryElement.firstChildElement( KVTML_TRANSLATION );
+            while( !translationElement.isNull() ) {
+                // <translation id="234"/>
+                int translationId = translationElement.attribute( KVTML_ID ).toInt();
+                m_allEntries.value(entryId)->translation(translationId)->setLeitnerBox(leitner);
+                translationElement = translationElement.nextSiblingElement( KVTML_TRANSLATION );
+            }
+            entryElement = entryElement.nextSiblingElement( KVTML_ENTRY );
+        }
+        leitnerElement = leitnerElement.nextSiblingElement( KVTML_CONTAINER );
+    }
+    return true;
+}
+
 bool KEduVocKvtml2Reader::readWordType( KEduVocWordType* parentContainer, QDomElement &typeElement )
 {
     // set type and specialtype
@@ -513,25 +570,25 @@ bool KEduVocKvtml2Reader::readWordType( KEduVocWordType* parentContainer, QDomEl
     if ( !specialType.isEmpty() ) {
         // get the localized version
         if ( specialType == KVTML_SPECIALWORDTYPE_NOUN ) {
-            wordTypeContainer->setWordType(KEduVocWordType::Noun);
+            wordTypeContainer->setWordType(KEduVocWordFlag::Noun);
         }
         if ( specialType == KVTML_SPECIALWORDTYPE_VERB ) {
-            wordTypeContainer->setWordType(KEduVocWordType::Verb);
+            wordTypeContainer->setWordType(KEduVocWordFlag::Verb);
         }
         if ( specialType == KVTML_SPECIALWORDTYPE_ADVERB ) {
-            wordTypeContainer->setWordType(KEduVocWordType::Adverb);
+            wordTypeContainer->setWordType(KEduVocWordFlag::Adverb);
         }
         if ( specialType == KVTML_SPECIALWORDTYPE_ADJECTIVE ) {
-            wordTypeContainer->setWordType(KEduVocWordType::Adjective);
+            wordTypeContainer->setWordType(KEduVocWordFlag::Adjective);
         }
         if ( specialType == KVTML_SPECIALWORDTYPE_NOUN_MALE ) {
-            wordTypeContainer->setWordType(KEduVocWordType::NounMale);
+            wordTypeContainer->setWordType(KEduVocWordFlag::Noun | KEduVocWordFlag::Masculine);
         }
         if ( specialType == KVTML_SPECIALWORDTYPE_NOUN_FEMALE ) {
-            wordTypeContainer->setWordType(KEduVocWordType::NounFemale);
+            wordTypeContainer->setWordType(KEduVocWordFlag::Noun | KEduVocWordFlag::Feminine);
         }
         if ( specialType == KVTML_SPECIALWORDTYPE_NOUN_NEUTRAL ) {
-            wordTypeContainer->setWordType(KEduVocWordType::NounNeutral);
+            wordTypeContainer->setWordType(KEduVocWordFlag::Noun| KEduVocWordFlag::Neuter);
         }
     } // special type
 
@@ -556,8 +613,7 @@ bool KEduVocKvtml2Reader::readWordType( KEduVocWordType* parentContainer, QDomEl
     return true;
 }
 
-
-bool KEduVocKvtml2Reader::readTenses( QDomElement &tensesElement )
+QStringList KEduVocKvtml2Reader::readTenses( QDomElement &tensesElement )
 {
     QStringList tenses;
 
@@ -569,27 +625,9 @@ bool KEduVocKvtml2Reader::readTenses( QDomElement &tensesElement )
         }
     }
 
-    m_doc->setTenseDescriptions( tenses );
-    return true;
+    return tenses;
 }
 
-/*
-bool KEduVocKvtml2Reader::readUsages( QDomElement &usagesElement )
-{
-    QStringList usages;
-
-    QDomNodeList usageNodes = usagesElement.elementsByTagName( KVTML_USAGE );
-    for ( int i = 0; i < usageNodes.count(); ++i ) {
-        QDomElement currentElement = usageNodes.item( i ).toElement();
-        if ( currentElement.parentNode() == usagesElement ) {
-            m_doc->addUsage( currentElement.text() );
-        }
-    }
-
-    return true;
-}*/
-
-
 bool KEduVocKvtml2Reader::readComparison( QDomElement &domElementParent, KEduVocTranslation* translation )
 /*
  <comparison>
@@ -650,27 +688,36 @@ bool KEduVocKvtml2Reader::readPersonalPronoun(QDomElement & pronounElement, KEdu
 
     QDomElement personElement = pronounElement.firstChildElement( KVTML_GRAMMATICAL_NUMBER[0] );
     if ( !personElement.isNull() ) {
-        readPersonalPronounChild( personElement, pronoun, KEduVocConjugation::Singular );
+        readPersonalPronounChild( personElement, pronoun, KEduVocWordFlag::Singular );
     }
 
     personElement = pronounElement.firstChildElement( KVTML_GRAMMATICAL_NUMBER[1] );
     if ( !personElement.isNull() ) {
-        readPersonalPronounChild( personElement, pronoun, KEduVocConjugation::Dual );
+        readPersonalPronounChild( personElement, pronoun, KEduVocWordFlag::Dual );
     }
 
     personElement = pronounElement.firstChildElement( KVTML_GRAMMATICAL_NUMBER[2] );
     if ( !personElement.isNull() ) {
-        readPersonalPronounChild( personElement, pronoun, KEduVocConjugation::Plural );
+        readPersonalPronounChild( personElement, pronoun, KEduVocWordFlag::Plural );
     }
     return true;
 }
 
 
-bool KEduVocKvtml2Reader::readPersonalPronounChild(QDomElement & personElement, KEduVocPersonalPronoun & pronoun, KEduVocConjugation::ConjugationNumber number)
+bool KEduVocKvtml2Reader::readPersonalPronounChild(QDomElement & personElement, KEduVocPersonalPronoun & pronoun, KEduVocWordFlags number)
 {
-    for (int person = KEduVocConjugation::First; person <= KEduVocConjugation::ThirdNeutralCommon; person++) {
+    QMap<int, KEduVocWordFlag::Flags> persons;
+    persons[0] = KEduVocWordFlag::First;
+    persons[1] = KEduVocWordFlag::Second;
+    persons[2] = (KEduVocWordFlag::Flags)((int)KEduVocWordFlag::Third | (int)KEduVocWordFlag::Masculine);
+    persons[3] = (KEduVocWordFlag::Flags)((int)KEduVocWordFlag::Third | (int)KEduVocWordFlag::Feminine);
+    persons[4] = (KEduVocWordFlag::Flags)((int)KEduVocWordFlag::Third | (int)KEduVocWordFlag::Neuter);
+
+
+
+    for (int person = 0; person < 5; person++) {
         QDomElement currentElement = personElement.firstChildElement( KVTML_GRAMMATICAL_PERSON[person] );
-        pronoun.setPersonalPronoun( currentElement.text(), KEduVocConjugation::ConjugationPerson(person), number );
+        pronoun.setPersonalPronoun( currentElement.text(), persons[person] | number );
     }
 
     return true;
