@@ -12,6 +12,9 @@
 // Own
 #include "KdeMainWindow.h"
 
+// Qt
+#include <QtGui/QProgressBar>
+
 // KDE
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -38,15 +41,17 @@ MainWindow::MainWindow( const QString& marbleDataPath, QWidget *parent )
 
     setCentralWidget( m_part->widget() );
 
+    insertChildClient( m_part );
+
     setXMLFile( "marbleui.rc" );
 
     setStandardToolBarMenuEnabled( true );
 
-    insertChildClient( m_part );
-
     createGUI( 0 );
 
+    // Creating the plugin menus
     m_part->createInfoBoxesMenu();
+    m_part->createOnlineServicesMenu();
 
     setAutoSaveSettings();
 
