@@ -15,6 +15,7 @@
 // Qt
 #include <QtCore/QDir>
 
+using namespace Marble;
 
 CacheStoragePolicy::CacheStoragePolicy( const QString &cacheDirectory )
     : m_cache( cacheDirectory )
@@ -35,7 +36,7 @@ bool CacheStoragePolicy::fileExists( const QString &fileName ) const
 bool CacheStoragePolicy::updateFile( const QString &fileName, const QByteArray &data )
 {
     if ( !m_cache.insert( fileName, data ) ) {
-        m_errorMsg = "Unable to insert data into cache";
+        m_errorMsg = QObject::tr("Unable to insert data into cache");
         return false;
     }
 
@@ -69,3 +70,5 @@ quint64 CacheStoragePolicy::cacheLimit() const
 {
     return m_cache.cacheLimit();
 }
+
+#include "CacheStoragePolicy.moc"
