@@ -13,12 +13,15 @@
 //
 
 
-#ifndef __MARBLE__IMAGELOADTHREAD_H
-#define __MARBLE__IMAGELOADTHREAD_H
+#ifndef MARBLE_IMAGELOADTHREAD_H
+#define MARBLE_IMAGELOADTHREAD_H
 
 #include <QtCore/QThread>
 #include <QtGui/QImage>
 
+namespace Marble
+{
+
 class TileId;
 
 class ImageLoadThread : public QThread {
@@ -33,4 +36,6 @@ class ImageLoadThread : public QThread {
     void run();
 };
 
-#endif // __MARBLE__IMAGELOADTHREAD_H
+}
+
+#endif // MARBLE_IMAGELOADTHREAD_H
