@@ -14,31 +14,33 @@
 
 #include <QtCore/QVariant>
 #include "AbstractFileViewItem.h"
+#include "GeoDataDocument.h"
 
 namespace Marble
 {
 
-class GeoDataDocument;
-class PlaceMarkManager;
+class PlacemarkManager;
 
 class KmlFileViewItem : public AbstractFileViewItem
 {
   public:
-    KmlFileViewItem( PlaceMarkManager& manager, GeoDataDocument& document );
+    KmlFileViewItem( PlacemarkManager& manager, const GeoDataDocument& document );
     ~KmlFileViewItem();
 
     /*
      * AbstractFileViewItem methods
      */
     virtual void saveFile();
-    virtual void closeFile();
-    virtual QVariant data() const;
+    virtual void closeFile( int start, bool finalize = true );
+    virtual QVariant data( int role = Qt::DisplayRole ) const;
     virtual bool isShown() const;
     virtual void setShown( bool value );
+    virtual int size() const;
 
+    GeoDataDocument* document();
   private:
-    PlaceMarkManager&   m_placeMarkManager;
-    GeoDataDocument&        m_document;
+    PlacemarkManager&   m_placemarkManager;
+    GeoDataDocument    m_document;
 };
 
 }
