@@ -161,7 +161,7 @@ QStringList MapThemeManager::findMapThemes( const QString& basePath )
     QStringListIterator it( mapDirs );
     while ( it.hasNext() ) {
         QString themeDir = it.next() + '/';
-        QString themeDirName = QDir( themeDir ).path().section( "/", -2, -1);
+        QString themeDirName = QDir( themeDir ).path().section( '/', -2, -1);
         QStringList tmp = ( QDir( themeDir ) ).entryList( QStringList( "*.dgml" ),
                                               QDir::Files | QDir::NoSymLinks );
         if ( !tmp.isEmpty() ) {
@@ -173,9 +173,6 @@ QStringList MapThemeManager::findMapThemes( const QString& basePath )
         }
     }
 
-//     for (int i = 0; i < mapFiles.size(); ++i)
-//         qDebug() << basePath << "-Files: " << mapFiles.at(i);
-
     return mapFiles;
 }
 
@@ -195,9 +192,6 @@ QStringList MapThemeManager::findMapThemes()
         }
     }
 
-    for (int i = 0; i < allMapFiles.size(); ++i)
-       qDebug() << "Files: " << allMapFiles.at(i);
-
     return allMapFiles;
 }
 
@@ -233,6 +227,7 @@ QList<QStandardItem *> MapThemeManager::createMapThemeRow( QString const& mapThe
         //       For now maxIconSize already equals what's expected by the listview.
         QSize maxIconSize( 136, 136 );
         if ( themeIconPixmap.size() != maxIconSize ) {
+            qDebug() << "Smooth scaling theme icon";
             themeIconPixmap = themeIconPixmap.scaled( maxIconSize, 
                                                     Qt::KeepAspectRatio,
                                                     Qt::SmoothTransformation );
@@ -367,31 +362,4 @@ void MapThemeManager::addMapThemePaths( const QString& mapPathName, QStringList&
     }
 }
 
-/*
-//  Should we put this into 
-//  static QString MapThemeManager::suggestTheme( QString themeSuggestedBySettings ); 
-//  ??
-
-    QStringList  mapthemedirs = findMapThemes( "maps/" );
-    QString      selectedmap;
-
-    // We need at least one maptheme to run Marble.
-    if ( mapthemedirs.count() == 0 ) {
-        qDebug() << "Could not find any maps! Exiting ...";
-        exit(-1);
-    }
-
-    // If any map directories were found, try to find the default map:
-    // srtm.  If we can find that, just grab the first one.
-    if ( mapthemedirs.count() >= 1 ) {
-        QStringList  tmp = mapthemedirs.filter( "srtm.dgml" );
-        if ( tmp.count() >= 1 )
-            selectedmap = tmp[0];
-        else
-            selectedmap = mapthemedirs[0];
-    }
-
-//    setMapTheme( selectedmap, parent, Spherical );
-*/
-
 #include "MapThemeManager.moc"
