@@ -8,18 +8,14 @@
 // Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
 // Copyright 2007      Inge Wallin  <ingwa@kde.org>"
 // Copyright 2008      Jens-Michael Hoffmann <jensmh@gmx.de>
-// Copyright 2008      Patrick Spendrin <ps_ml@gmx.de>
+// Copyright 2008-2009      Patrick Spendrin <ps_ml@gmx.de>
 //
 
 #include "MarbleModel.h"
 
 #include <cmath>
 
-#if QT_VERSION < 0x040400
-# include <qatomic.h>
-#else
-# include <QtCore/QAtomicInt>
-#endif
+#include <QtCore/QAtomicInt>
 #include <QtCore/QDebug>
 #include <QtCore/QTime>
 #include <QtCore/QTimer>
@@ -43,14 +39,13 @@
 
 #include "DgmlAuxillaryDictionary.h"
 
+#include "FileStoragePolicy.h"
 #include "GeoPainter.h"
 #include "FileViewModel.h"
 #include "SphericalScanlineTextureMapper.h"
 #include "EquirectScanlineTextureMapper.h"
 #include "MercatorScanlineTextureMapper.h"
-#include "GeoPolygon.h"
 #include "gps/GpxFileModel.h"
-#include "GridMap.h"
 #include "HttpDownloadManager.h"
 #include "KmlFileViewItem.h"
 #include "LayerManager.h"
@@ -59,9 +54,10 @@
 #include "MarblePlacemarkModel.h"
 #include "MarbleGeometryModel.h"
 #include "MergedLayerDecorator.h"
-#include "PlaceMarkManager.h"
-#include "PlaceMarkLayout.h"
-#include "PlaceMarkPainter.h"
+#include "PlacemarkManager.h"
+#include "PlacemarkLayout.h"
+#include "PlacemarkPainter.h"
+#include "Planet.h"
 #include "StoragePolicy.h"
 #include "SunLocator.h"
 #include "TextureColorizer.h"
@@ -76,10 +72,6 @@
 namespace Marble
 {
 
-#if QT_VERSION < 0x040400
-    typedef QAtomic QAtomicInt;
-#endif
-
 class MarbleModelPrivate
 {
  public:
@@ -87,14 +79,20 @@ class MarbleModelPrivate
         : m_parent( parent ),
           m_dataFacade( 0 ),
           m_mapTheme( 0 ),
-          m_layerManager( 0 )
+          m_layerManager( 0 ),
+          m_downloadManager( new HttpDownloadManager( QUrl(), new FileStoragePolicy(
+                                                                   MarbleDirs::localPath() )))
     {
     }
 
-    void  resize( int width, int height );
-    void  notifyModelChanged();
-    void  geoDataDocumentLoaded( GeoDataDocument& document );
-    void geoDataDocumentAdded( GeoDataDocument* document );
+    ~MarbleModelPrivate()
+    {
+        delete m_downloadManager;
+    }
+
+    void resize( int width, int height );
+    void notifyModelChanged();
+    void geoDataDocumentAdded( const GeoDataDocument& document );
 
     static QAtomicInt       refCounter;
     MarbleModel             *m_parent;
@@ -111,13 +109,13 @@ class MarbleModelPrivate
     AbstractScanlineTextureMapper   *m_texmapper;
 
     static VectorComposer   *m_veccomposer; // FIXME: Make not a pointer.
-    GridMap                 *m_gridmap;
 
     // Places on the map
-    PlaceMarkManager        *m_placemarkmanager;
+    PlacemarkManager        *m_placemarkmanager;
     MarblePlacemarkModel    *m_placemarkmodel;
-    PlaceMarkLayout         *m_placeMarkLayout;
+    PlacemarkLayout         *m_placemarkLayout;
     MarbleGeometryModel     *m_geometrymodel;
+    QSortFilterProxyModel   *m_popSortModel;
 
     // Misc stuff.
     ExtDateTime             *m_dateTime;
@@ -133,7 +131,8 @@ class MarbleModelPrivate
 
     QTimer                  *m_timer;
 
-    FileViewModel           *m_fileviewmodel;
+
+    Planet                  *m_planet;
 };
 
 VectorComposer      *MarbleModelPrivate::m_veccomposer = 0;
@@ -158,58 +157,63 @@ MarbleModel::MarbleModel( QObject *parent )
     connect( d->m_timer, SIGNAL( timeout() ),
              this,       SIGNAL( timeout() ) );
 
-    d->m_downloadManager = 0;
-
     d->m_tileLoader = new TileLoader( d->m_downloadManager, this );
 
     d->m_texmapper = 0;
-    d->m_gridmap      = new GridMap( this );
     
     if( MarbleModelPrivate::refCounter == 1 ) {
         d->m_veccomposer = new VectorComposer();
+        d->m_texcolorizer = 0;
         /* d->m_texcolorizer is not initialized here since it takes a long time
            to create the palette and it might not even be used. Instead it's created
            in setMapTheme if the theme being loaded does need it. If the theme
            doesn't need it, it's left as is. */
     }
 
-    d->m_placemarkmanager   = new PlaceMarkManager();
+    d->m_placemarkmanager = new PlacemarkManager();
 
-    connect( d->m_placemarkmanager, SIGNAL( geoDataDocumentLoaded( GeoDataDocument& ) ),
-             this,                  SLOT( geoDataDocumentLoaded( GeoDataDocument& ) ) );
-    connect( d->m_placemarkmanager, SIGNAL( geoDataDocumentAdded( GeoDataDocument* ) ),
-             this,                  SLOT( geoDataDocumentAdded( GeoDataDocument* ) ) );
+    connect( d->m_placemarkmanager, SIGNAL( geoDataDocumentAdded( const GeoDataDocument& ) ),
+             this,                  SLOT( geoDataDocumentAdded( const GeoDataDocument& ) ) );
 
     d->m_placemarkmodel = new MarblePlacemarkModel( d->m_placemarkmanager, this );
-    d->m_placemarkselectionmodel = new QItemSelectionModel( d->m_placemarkmodel );
+    d->m_popSortModel = new QSortFilterProxyModel( this );
+
+    d->m_popSortModel->setSourceModel( d->m_placemarkmodel );
+//    d->m_popSortModel->setSortLocaleAware( true );
+//    d->m_popSortModel->setDynamicSortFilter( true );
+    d->m_popSortModel->setSortRole( MarblePlacemarkModel::PopularityIndexRole );
+    d->m_popSortModel->sort( 0, Qt::DescendingOrder );
+    
+    d->m_placemarkselectionmodel = new QItemSelectionModel( d->m_popSortModel );
+
     d->m_geometrymodel = new MarbleGeometryModel();
     d->m_placemarkmanager->setGeoModel( d->m_geometrymodel );
 
-    d->m_placeMarkLayout = new PlaceMarkLayout( this );
+    d->m_placemarkLayout = new PlacemarkLayout( this );
     connect( d->m_placemarkmanager,         SIGNAL( finalize() ),
-             d->m_placeMarkLayout,          SLOT( requestStyleReset() ) );
+             d->m_placemarkLayout,          SLOT( requestStyleReset() ) );
     connect( d->m_placemarkselectionmodel,  SIGNAL( selectionChanged( QItemSelection,
                                                                       QItemSelection) ),
-             d->m_placeMarkLayout,          SLOT( requestStyleReset() ) );
+             d->m_placemarkLayout,          SLOT( requestStyleReset() ) );
     connect( d->m_placemarkmodel,           SIGNAL( layoutChanged() ),
-             d->m_placeMarkLayout,          SLOT( requestStyleReset() ) );
-
-    d->m_gpxFileModel = new GpxFileModel( this );
-    d->m_gpsLayer = new GpsLayer( d->m_gpxFileModel );
-
-    connect( d->m_gpxFileModel, SIGNAL( updateRegion( BoundingBox& ) ),
-             this,              SIGNAL( regionChanged( BoundingBox& ) ) );
+             d->m_placemarkLayout,          SLOT( requestStyleReset() ) );
 
     /*
      * Create FileViewModel
      */
-    d->m_fileviewmodel = new FileViewModel( this );
+    connect( fileViewModel(), SIGNAL( modelChanged() ),
+             this,            SIGNAL( modelChanged() ) );
 
-    connect( d->m_fileviewmodel, SIGNAL( updateRegion( BoundingBox& ) ),
-             this,               SIGNAL( regionChanged( BoundingBox& ) ) );
+    d->m_gpxFileModel = new GpxFileModel( this );
+    d->m_gpsLayer = new GpsLayer( d->m_gpxFileModel );
+
+    connect( fileViewModel(), SIGNAL(layoutChanged()),
+             d->m_gpsLayer, SLOT(clearModel() ) );
 
     d->m_dateTime       = new ExtDateTime();
-    d->m_sunLocator     = new SunLocator( d->m_dateTime );
+    /* Assume we are dealing with the earth */
+    d->m_planet = new Planet( "earth" );
+    d->m_sunLocator     = new SunLocator( d->m_dateTime, d->m_planet );
     d->m_layerDecorator = new MergedLayerDecorator( d->m_sunLocator );
 
     connect(d->m_dateTime,   SIGNAL( timeChanged() ),
@@ -225,16 +229,14 @@ MarbleModel::~MarbleModel()
     delete d->m_texmapper;
 
     delete d->m_tileLoader; // disconnects from downloadManager in dtor
-    delete d->m_downloadManager;
 
     if( MarbleModelPrivate::refCounter == 1 ) {
         delete d->m_veccomposer;
         delete d->m_texcolorizer;
-        MarbleModelPrivate::refCounter.deref();
     }
-    delete d->m_gridmap;
     delete d->m_geometrymodel;
     delete d->m_placemarkmodel;
+    delete d->m_popSortModel;
     delete d->m_placemarkmanager;
     delete d->m_gpsLayer;
     delete d->m_mapTheme;
@@ -244,7 +246,9 @@ MarbleModel::~MarbleModel()
     delete d->m_layerDecorator;
     delete d->m_sunLocator;
     delete d->m_dateTime;
+    delete d->m_planet;
     delete d;
+    MarbleModelPrivate::refCounter.deref();
     qDebug() << "Model deleted:" << this;
 }
 
@@ -314,6 +318,12 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
     else
         qDebug() << "Does not contain any vector layers! ";
 */
+    //Don't change the planet unless we have to...
+    if( d->m_mapTheme->head()->target().toLower() != d->m_planet->id() ) {
+        qDebug() << "Changing Planet";
+        *(d->m_planet) = Planet( d->m_mapTheme->head()->target().toLower() );
+        sunLocator()->setPlanet(d->m_planet);
+    }
 
     if ( d->m_mapTheme->map()->hasTextureLayers() ) {
         // If the tiles aren't already there, put up a progress dialog
@@ -395,21 +405,25 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
     }
 
     d->m_geometrymodel->setGeoDataRoot( 0 );
-    QStringList loadedContainers = d->m_placemarkmanager->model()->containers();
+    QStringList loadedContainers = d->m_placemarkmanager->containers();
     QStringList loadList;
-    QVector<GeoSceneLayer*>::const_iterator it = d->m_mapTheme->map()->layers().constBegin();
-    QVector<GeoSceneLayer*>::const_iterator end = d->m_mapTheme->map()->layers().constEnd();
+    const QVector<GeoSceneLayer*> & layers = d->m_mapTheme->map()->layers();
+    QVector<GeoSceneLayer*>::const_iterator it = layers.constBegin();
+    QVector<GeoSceneLayer*>::const_iterator end = layers.constEnd();
     for (; it != end; ++it) {
         GeoSceneLayer* layer = *it;
         if ( layer->backend() == dgml::dgmlValue_geodata && layer->datasets().count() > 0 ) {
             // look for documents
-            QVector<GeoSceneAbstractDataset*>::const_iterator itds = layer->datasets().constBegin();
-            QVector<GeoSceneAbstractDataset*>::const_iterator endds = layer->datasets().constEnd();
+            const QVector<GeoSceneAbstractDataset*> & datasets = layer->datasets();
+            QVector<GeoSceneAbstractDataset*>::const_iterator itds = datasets.constBegin();
+            QVector<GeoSceneAbstractDataset*>::const_iterator endds = datasets.constEnd();
             for (; itds != endds; ++itds) {
                 GeoSceneAbstractDataset* dataset = *itds;
                 if( dataset->fileFormat() == "KML" ) {
-                    loadedContainers.removeOne( reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename() );
-                    loadList << reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename();
+                    QString containername = reinterpret_cast<GeoSceneXmlDataSource*>(dataset)->filename();
+                    if( containername.endsWith(".kml") ) containername.remove(".kml");
+                    loadedContainers.removeOne( containername );
+                    loadList << containername;          
                 }
             }
         }
@@ -417,17 +431,18 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
     // unload old standard Placemarks which are not part of the new map
     foreach(const QString& container, loadedContainers) {
         loadedContainers.pop_front();
-        d->m_placemarkmanager->model()->removePlaceMarks( container, loadedContainers.isEmpty() );
+        d->m_placemarkmanager->removePlacemarkKey( container );
     }
     // load new standard Placemarks
     foreach(const QString& container, loadList) {
         loadList.pop_front();
-        d->m_placemarkmanager->addPlaceMarkFile( container, loadList.isEmpty() );
+        d->m_placemarkmanager->addPlacemarkFile( container, loadList.isEmpty() );
     }
-    
+    d->notifyModelChanged();
+
 
     // FIXME: Still needs to get fixed for the DGML2 refactoring
-//    d->m_placeMarkLayout->placeMarkPainter()->setDefaultLabelColor( d->m_maptheme->labelColor() );
+//    d->m_placemarkLayout->placemarkPainter()->setDefaultLabelColor( d->m_maptheme->labelColor() );
 
     if( !d->m_mapTheme->map()->filters().isEmpty() ) {
         GeoSceneFilter *filter= d->m_mapTheme->map()->filters().first();
@@ -461,11 +476,11 @@ void MarbleModel::setMapTheme( GeoSceneDocument* mapTheme,
     }
     qDebug() << "THEME CHANGED: ***" << mapTheme->head()->mapThemeId();
     emit themeChanged( mapTheme->head()->mapThemeId() );
-    d->m_sunLocator->setBody(d->m_mapTheme->head()->target().toLower());
 
     d->m_layerManager->syncViewParamsAndPlugins( mapTheme );
 
     d->notifyModelChanged();
+    d->m_placemarkLayout->requestStyleReset();
 }
 
 void MarbleModel::setupTextureMapper( Projection projection )
@@ -532,6 +547,10 @@ void MarbleModel::paintGlobe( GeoPainter *painter,
     GeoSceneLayer *layer = 
         static_cast<GeoSceneLayer*>( d->m_mapTheme->map()->layer( themeID ) );
 
+    QStringList renderPositions;
+    renderPositions << "STARS" << "BEHIND_TARGET";
+    d->m_layerManager->renderLayers( painter, viewParams, renderPositions );
+        
     if ( redrawBackground ) {
         if ( d->m_mapTheme->map()->hasTextureLayers() ) {
 
@@ -575,59 +594,26 @@ void MarbleModel::paintGlobe( GeoPainter *painter,
 
 //    qDebug( "Painted in %ims", t.elapsed() );
 
+    renderPositions.clear();
+    renderPositions << "SURFACE";
+
     // Paint the vector layer.
     if ( d->m_mapTheme->map()->hasVectorLayers() ) {
 
         if ( !d->m_mapTheme->map()->hasTextureLayers() ) {
             d->m_veccomposer->paintBaseVectorMap( painter, viewParams );
         }
+
+        d->m_layerManager->renderLayers( painter, viewParams, renderPositions );
+
         // Add further Vectors
         d->m_veccomposer->paintVectorMap( painter, viewParams );
     }
-
-    // Paint the lon/lat grid around the earth.
-    bool showGrid;
-
-    viewParams->propertyValue( "coordinate-grid", showGrid );
-
-    if ( showGrid ) {
-        QPen  gridpen( QColor( 231, 231, 231, 255 ) );
-
-        // FIXME: Why would the createFoo() functions be exposed in
-        //        the class GridMap?  Shouldn't just a call to
-        //        paintGrid() or paintEquator be enough?  The internal
-        //        create...() functions should be private and not
-        //        exposed to the outside.
-
-        // Create and paint a grid
-        d->m_gridmap->createGrid( viewParams->viewport() );
-        d->m_gridmap->setPen( gridpen );
-
-        bool antialiased = false;
-
-        if (   viewParams->mapQuality() == Marble::High
-            || viewParams->mapQuality() == Marble::Print ) {
-                antialiased = true;
-        }
-
-        d->m_gridmap->paintGridMap( painter, antialiased );
-
-        // Create and paint the tropics and polar circles
-        d->m_gridmap->createTropics( viewParams->viewport() );
-        gridpen.setStyle( Qt::DotLine );
-        // gridpen.setWidthF( 1.5f );
-        d->m_gridmap->setPen( gridpen );
-        d->m_gridmap->paintGridMap( painter, antialiased );
-
-        // Create and paint Equator
-        d->m_gridmap->createEquator( viewParams->viewport() );
-        // gridpen.setWidthF( 2.0f );
-        d->m_gridmap->setPen( gridpen );
-        d->m_gridmap->paintGridMap( painter, antialiased );
+    else {
+        d->m_layerManager->renderLayers( painter, viewParams, renderPositions );        
     }
 
-    // Paint the GeoDataPlaceMark layer
-#ifndef KML_GSOC
+    // Paint the GeoDataPlacemark layer
     bool showPlaces, showCities, showTerrain, showOtherPlaces;
 
     viewParams->propertyValue( "places", showPlaces );
@@ -636,67 +622,34 @@ void MarbleModel::paintGlobe( GeoPainter *painter,
     viewParams->propertyValue( "otherplaces", showOtherPlaces );
 
     if ( showPlaces && ( showCities || showTerrain || showOtherPlaces )
-         && d->m_placemarkmodel->rowCount() > 0 )
+         && d->m_popSortModel->rowCount() > 0 )
     {
-        d->m_placeMarkLayout->paintPlaceFolder( painter, viewParams,
-                                                d->m_placemarkmodel,
+        d->m_placemarkLayout->paintPlaceFolder( painter, viewParams,
+                                                d->m_popSortModel,
                                                 d->m_placemarkselectionmodel );
     }
-#else
-    /*
-     * Iterate over our KMLFolders and show placemarks from each folderList
-     * This folder list also will be displayed in MarbleControlBox
-     * So user could enable/disable each folder
-     */
-    if ( viewParams->m_showPlaceMarks ) {
-        QTime t;
-        t.start ();
-
-        const QList < GeoDataFolder* >& folderList = d->m_placemarkmanager->getFolderList();
-
-        bool firstTime = true;
-
-        for ( QList<GeoDataFolder*>::const_iterator iterator = folderList.constBegin();
-            iterator != folderList.constEnd();
-            ++iterator )
-        {
-            GeoDataFolder& folder = *( *iterator );
-
-            /*
-             * Show only placemarks which are visible
-             */
-            if ( folder.isVisible() ) {
-
-                PlaceMarkContainer& container = folder.activePlaceMarkContainer( *viewParams );
-
-                d->m_placeMarkLayout->paintPlaceFolder( painter, viewParams,
-                                                        &container, firstTime );
-
-                firstTime = false;
-            }
-        }
-
-        qDebug("Paint kml folder list. Elapsed: %d", t.elapsed());
-    }
-#endif
 
     // Paint the Gps Layer
-    d->m_gpsLayer->setVisible( viewParams->showGps() );
+//    d->m_gpsLayer->setVisible( viewParams->showGps() );
     //FIXME:We might just send ViewParams instead of this bunch of parameters
     d->m_gpsLayer->paintLayer( painter,
                                viewParams->canvasImage()->size(),
-                               viewParams,
-                               viewParams->viewport()->boundingBox() );
-    d->m_layerManager->renderLayers( painter, viewParams );
+                               viewParams );
+
+    renderPositions.clear();
+    renderPositions << "HOVERS_ABOVE_SURFACE" << "ATMOSPHERE"
+                    << "ORBIT" << "ALWAYS_ON_TOP" << "FLOAT_ITEM";
+                               
+    d->m_layerManager->renderLayers( painter, viewParams, renderPositions );
 }
 
 
-QAbstractItemModel *MarbleModel::placeMarkModel() const
+QAbstractItemModel *MarbleModel::placemarkModel() const
 {
     return d->m_placemarkmodel;
 }
 
-QItemSelectionModel *MarbleModel::placeMarkSelectionModel() const
+QItemSelectionModel *MarbleModel::placemarkSelectionModel() const
 {
     return d->m_placemarkselectionmodel;
 }
@@ -706,74 +659,65 @@ QAbstractItemModel *MarbleModel::geometryModel() const
     return d->m_geometrymodel;
 }
 
-VectorComposer    *MarbleModel::vectorComposer()   const
+VectorComposer *MarbleModel::vectorComposer() const
 {
     return d->m_veccomposer;
 }
 
-TextureColorizer  *MarbleModel::textureColorizer() const
+TextureColorizer *MarbleModel::textureColorizer() const
 {
     return d->m_texcolorizer;
 }
 
-AbstractScanlineTextureMapper    *MarbleModel::textureMapper()    const
+AbstractScanlineTextureMapper *MarbleModel::textureMapper() const
 {
     return d->m_texmapper;
 }
 
-PlaceMarkLayout *MarbleModel::placeMarkLayout() const
+PlacemarkLayout *MarbleModel::placemarkLayout() const
 {
-    return d->m_placeMarkLayout;
+    return d->m_placemarkLayout;
 }
 
-GpsLayer *MarbleModel::gpsLayer()         const
+GpsLayer *MarbleModel::gpsLayer() const
 {
     return d->m_gpsLayer;
 }
 
-GpxFileModel *MarbleModel::gpxFileModel()   const
+GpxFileModel *MarbleModel::gpxFileModel() const
 {
     return d->m_gpxFileModel;
 }
 
 FileViewModel *MarbleModel::fileViewModel() const
 {
-    return d->m_fileviewmodel;
+    return d->m_placemarkmanager->fileViewModel();
 }
 
-void MarbleModel::addPlaceMarkFile( const QString& filename )
+void MarbleModel::addPlacemarkFile( const QString& filename )
 {
     d->m_placemarkmanager->loadKml( filename, false );
 
     d->notifyModelChanged();
 }
 
-void MarbleModel::addPlaceMarkData( const QString& data, const QString& key )
+void MarbleModel::addPlacemarkData( const QString& data, const QString& key )
 {
-    QStringList loadedContainers = d->m_placemarkmanager->model()->containers();
-    if( loadedContainers.contains( key ) )
-    {
-        d->m_placemarkmanager->model()->removePlaceMarks( key, false );
-    }
-    d->m_placemarkmanager->loadKmlFromData( data, key, false );
+    d->m_placemarkmanager->addPlacemarkData( data, key );
 
     d->notifyModelChanged();
 }
 
-void MarbleModel::removePlaceMarkKey( const QString& key )
+void MarbleModel::removePlacemarkKey( const QString& key )
 {
-    QStringList loadedContainers = d->m_placemarkmanager->model()->containers();
-    if( loadedContainers.contains( key ) )
-    {
-        d->m_placemarkmanager->model()->removePlaceMarks( key, false );
-    }
+    d->m_placemarkmanager->removePlacemarkKey( key );
 
     d->notifyModelChanged();
 }
 
-QVector<QPersistentModelIndex> MarbleModel::whichFeatureAt( const QPoint& curpos ) const
+QVector<QModelIndex> MarbleModel::whichFeatureAt( const QPoint& curpos ) const
 {
-    return d->m_placeMarkLayout->whichPlaceMarkAt( curpos );
+    return d->m_placemarkLayout->whichPlacemarkAt( curpos );
 }
 
 void MarbleModelPrivate::notifyModelChanged()
@@ -781,27 +725,17 @@ void MarbleModelPrivate::notifyModelChanged()
     emit m_parent->modelChanged();
 }
 
-void MarbleModelPrivate::geoDataDocumentLoaded( GeoDataDocument& document )
+void MarbleModelPrivate::geoDataDocumentAdded( const GeoDataDocument& document )
 {
-    AbstractFileViewItem* item = new KmlFileViewItem( *m_placemarkmanager,
-                                                      document );
+/*    QVector<GeoDataFeature>::Iterator end = document->end();
+    QVector<GeoDataFeature>::Iterator itr = document->begin();
+    for ( ; itr != end; ++itr ) {
+        // use *itr (or itr.value()) here
+        QString styleUrl = itr->styleUrl().remove('#');
+        itr->setStyle( &document->style( styleUrl ) );
+    }
 
-    m_fileviewmodel->append( item );
-}
-
-void MarbleModelPrivate::geoDataDocumentAdded( GeoDataDocument* document )
-{
-    AbstractFileViewItem* item = new KmlFileViewItem( *m_placemarkmanager,
-                                                      *document );
-
-    foreach(GeoDataPlacemark* placemark, document->placemarks())
-    {
-        QString styleUrl = placemark->styleUrl().remove('#');
-        placemark->setStyle( document->style( styleUrl ) );
-    };
-    m_fileviewmodel->append( item );
-    
-    m_geometrymodel->setGeoDataRoot( document );
+    m_geometrymodel->setGeoDataRoot( document );*/
 }
 
 void MarbleModel::update()
@@ -812,45 +746,12 @@ void MarbleModel::update()
 
 qreal MarbleModel::planetRadius()   const
 {
-    if ( d->m_mapTheme ) {
-        QString target = d->m_mapTheme->head()->target().toLower();
+    return d->m_planet->radius();
+}
 
-        // I'd like to be able to use strings in switch statements ... 
-
-        // Make sure to use the radius, not the diameter!
-
-        // planets
-               if ( target == "mercury" ) {
-            return  2440000.0;
-        } else if ( target == "venus" ) {
-            return  6051800.0;
-        } else if ( target == "earth" ) {
-            return  6378000.0;
-        } else if ( target == "mars" ) {
-            return  3397000.0;
-        } else if ( target == "jupiter" ) {
-            return  71492000.0;
-        } else if ( target == "saturn" ) {
-            return  60268000.0;
-        } else if ( target == "uranus" ) {
-            return  25559000.0;
-        } else if ( target == "neptune" ) {
-            return  24766000.0;
-
-        // dwarf planets ... (everybody likes pluto)
-        } else if ( target == "pluto" ) {
-            return  1151000.0;
-
-        // sun and moon
-        } else if ( target == "sun" ) {
-            return  695000000.0;
-        } else if ( target == "moon" ) {
-            return  1738000.0;
-        }
-    }
-
-    // Fallback to assuming that we deal with the earth
-    return 6378000.0;
+QString MarbleModel::planetName()   const
+{
+    return d->m_planet->name();
 }
 
 ExtDateTime* MarbleModel::dateTime() const
@@ -929,33 +830,57 @@ void MarbleModel::clearPersistentTileCache()
     }
 }
 
-void MarbleModel::paintTile(TextureTile* tile, int x, int y, int level,
-                            GeoSceneTexture *textureLayer, bool requestTileUpdate)
+void MarbleModel::paintTile( TextureTile* tile, int x, int y, int level,
+                             GeoSceneTexture *textureLayer, bool requestTileUpdate )
 {
-//    qDebug() << "MarbleModel::paintTile: " << "x: " << x << "y:" << y << "level: " << level << "requestTileUpdate" << requestTileUpdate;
+//    qDebug() << "MarbleModel::paintTile: " << "x: " << x << "y:" << y << "level: " << level
+//             << "requestTileUpdate" << requestTileUpdate;
     
     if ( d->m_downloadManager != 0 ) {
         connect( d->m_layerDecorator, SIGNAL( downloadTile( QUrl, QString, QString ) ),
                  d->m_downloadManager, SLOT( addJob( QUrl, QString, QString ) ) );
     }
 
-    d->m_layerDecorator->setInfo(x, y, level, tile->id());
-    d->m_layerDecorator->setTile(tile->tile());
-        
-    d->m_layerDecorator->paint("maps/" + textureLayer->sourceDir(), mapTheme() );
-    tile->loadTile(requestTileUpdate);
+    d->m_layerDecorator->setInfo( x, y, level, tile->id() );
+    d->m_layerDecorator->setTile( tile->tile() );
+
+    d->m_layerDecorator->paint( "maps/" + textureLayer->sourceDir(), mapTheme() );
+    tile->initJumpTables( requestTileUpdate );
 }
 
-QList<MarbleRenderPlugin *> MarbleModel::renderPlugins() const
+QList<RenderPlugin *> MarbleModel::renderPlugins() const
 {
     return d->m_layerManager->renderPlugins();
 }
 
-QList<MarbleAbstractFloatItem *> MarbleModel::floatItems() const
+QList<AbstractFloatItem *> MarbleModel::floatItems() const
 {
     return d->m_layerManager->floatItems();
 }
 
+QList<AbstractDataPlugin *> MarbleModel::dataPlugins()  const
+{
+    return d->m_layerManager->dataPlugins();
+}
+
+QList<AbstractDataPluginItem *> MarbleModel::whichItemAt( const QPoint& curpos ) const
+{
+    return d->m_layerManager->whichItemAt( curpos );
+}
+
+Planet* MarbleModel::planet() const
+{
+    return d->m_planet;
+}
+
+int MarbleModel::tileZoomLevel() const
+{
+    if (!d->m_texmapper)
+        return -1;
+
+    return d->m_texmapper->tileZoomLevel();
+}
+
 }
 
 #include "MarbleModel.moc"
