@@ -16,7 +16,6 @@
 #include <stdlib.h>
 
 #include <QtCore/QVector>
-#include <QtCore/QTime>
 #include <QtCore/QDebug>
 #include <QtGui/QColor>
 
@@ -25,43 +24,31 @@
 #include "GeoPainter.h"
 #include "GeoPolygon.h"
 #include "ViewportParams.h"
-#include "AbstractProjectionHelper.h"
-
-#ifdef Q_CC_MSVC
-static double msvc_atanh(double x)
-{
-  return ( 0.5 * log( ( 1.0 + x ) / ( 1.0 - x ) ) );
-}
-#define atanh msvc_atanh
-#endif
+#include "MathHelper.h"
 
 // #define VECMAP_DEBUG 
 
+using namespace Marble;
 
 VectorMap::VectorMap()
+    : m_zlimit( 0.0 ),
+      m_plimit( 0.0 ),
+      m_zBoundingBoxLimit( 0.0 ),
+      m_zPointLimit( 0.0 ),
+      m_imgrx( 0 ),
+      m_imgry( 0 ),
+      m_imgwidth( 0 ),
+      m_imgheight( 0 ),
+      m_brush( QBrush( QColor( 0, 0, 0 ) ) ),
+      // Initialising booleans for horizoncrossing
+      m_firsthorizon( false ),
+      m_lastvisible( false ),
+      m_currentlyvisible( false ),
+      m_horizonpair( false ),
+
+      m_rlimit( 0 )
+      // m_debugNodeCount( 0 )
 {
-
-    m_zlimit = 0.0; 
-    m_plimit = 0.0;
-    m_zBoundingBoxLimit = 0.0; 
-    m_zPointLimit = 0.0;
-
-    m_imgrx = 0; 
-    m_imgry = 0; 
-    m_imgwidth  = 0; 
-    m_imgheight = 0;
-
-    // Initialising booleans for horizoncrossing
-    m_horizonpair = false;
-    m_lastvisible = false;
-    m_currentlyvisible = false;
-    m_firsthorizon = false;
-
-    m_rlimit = 0;
-
-    m_brush = QBrush( QColor( 0, 0, 0 ) );
-
-    //	m_debugNodeCount = 0;
 }
 
 VectorMap::~VectorMap()
@@ -90,16 +77,16 @@ void VectorMap::sphericalCreateFromPntMap( const PntMap* pntmap,
 {
     clear();
 
-    // We must use double or int64 for the calculations because we
+    // We must use qreal or int64 for the calculations because we
     // square radius sometimes below, and it may cause an overflow. We
-    // choose double because of some sqrt() calculations.
-    double   radius     = viewport->radius();
-    double   imgradius2 = m_imgrx * m_imgrx + m_imgry * m_imgry;
+    // choose qreal because of some sqrt() calculations.
+    qreal   radius     = viewport->radius();
+    qreal   imgradius2 = m_imgrx * m_imgrx + m_imgry * m_imgry;
 
     // zlimit: describes the lowest z value of the sphere that is
     //         visible on the screen.  This should happen in the
     //         corners.
-    double zlimit = ( ( imgradius2 < radius * radius )
+    qreal zlimit = ( ( imgradius2 < radius * radius )
                       ? sqrt( 1 - imgradius2 / ( radius * radius ) )
                       : 0.0 );
     // qDebug() << "zlimit: " << zlimit;
@@ -118,18 +105,18 @@ void VectorMap::sphericalCreateFromPntMap( const PntMap* pntmap,
     Quaternion  qbound;
 
     viewport->planetAxis().inverse().toMatrix( m_rotMatrix );
-    GeoPolygon::PtrVector::Iterator       itPolyLine;
+    GeoPolygon::PtrVector::ConstIterator  itPolyLine = pntmap->constBegin();
     GeoPolygon::PtrVector::ConstIterator  itEndPolyLine = pntmap->constEnd();
 
     //	const int detail = 0;
     const int  detail = getDetailLevel( viewport->radius() );
 
-    for ( itPolyLine = const_cast<PntMap *>(pntmap)->begin();
-          itPolyLine < itEndPolyLine;
-          ++itPolyLine )
+    for (; itPolyLine != itEndPolyLine; ++itPolyLine )
     {
         // This sorts out polygons by bounding box which aren't visible at all.
         GeoDataCoordinates::PtrVector boundary = (*itPolyLine)->getBoundary();
+        // rather paint an invalid line then crashing here if the boundaries are not loaded yet
+        if(boundary.size() < 5) continue;
 
         for ( int i = 0; i < 5; ++i ) {
             qbound = boundary[i]->quaternion();
@@ -160,25 +147,23 @@ void VectorMap::rectangularCreateFromPntMap( const PntMap* pntmap,
     int  radius = viewport->radius();
 
     // Calculate translation of center point
-    double  centerLon;
-    double  centerLat;
+    qreal  centerLon;
+    qreal  centerLat;
     viewport->centerCoordinates( centerLon, centerLat );
 
-    double rad2Pixel = (float)( 2 * radius ) / M_PI;
-    double lon, lat;
-    double x, y;
+    qreal rad2Pixel = (float)( 2 * radius ) / M_PI;
+    qreal lon, lat;
+    qreal x, y;
 
     viewport->planetAxis().inverse().toMatrix( m_rotMatrix );
-    GeoPolygon::PtrVector::Iterator       itPolyLine;
+    GeoPolygon::PtrVector::ConstIterator  itPolyLine = pntmap->constBegin();
     GeoPolygon::PtrVector::ConstIterator  itEndPolyLine = pntmap->constEnd();
 
     ScreenPolygon  boundingPolygon;
     QRectF         visibleArea ( 0, 0, m_imgwidth, m_imgheight );
     const int      detail = getDetailLevel( radius );
 
-    for ( itPolyLine = const_cast<PntMap *>(pntmap)->begin();
-          itPolyLine < itEndPolyLine;
-          ++itPolyLine )
+    for (; itPolyLine != itEndPolyLine; ++itPolyLine )
     {
         // This sorts out polygons by bounding box which aren't visible at all.
         m_offset = 0;
@@ -188,10 +173,14 @@ void VectorMap::rectangularCreateFromPntMap( const PntMap* pntmap,
 
         // Let's just use the top left and the bottom right bounding
         // box point for this projection.
+
+        // rather paint an invalid line then crashing here if the boundaries are not loaded yet
+        if(boundary.size() < 3) continue;
+
         for ( int i = 1; i < 3; ++i ) {
             boundary[i]->geoCoordinates(lon, lat);
-            x = (double)(m_imgwidth)  / 2.0 - rad2Pixel * (centerLon - lon);
-            y = (double)(m_imgheight) / 2.0 + rad2Pixel * (centerLat - lat);
+            x = (qreal)(m_imgwidth)  / 2.0 - rad2Pixel * (centerLon - lon);
+            y = (qreal)(m_imgheight) / 2.0 + rad2Pixel * (centerLat - lat);
             boundingPolygon << QPointF( x, y );
         }
 
@@ -208,9 +197,17 @@ void VectorMap::rectangularCreateFromPntMap( const PntMap* pntmap,
         } while( ( (*itPolyLine)->getDateLine() != GeoPolygon::Even 
 		   && visibleArea.intersects( (QRectF)( boundingPolygon.boundingRect() ) ) )
 		 || ( (*itPolyLine)->getDateLine() == GeoPolygon::Even
-		      && ( visibleArea.intersects( QRectF( boundingPolygon.at(1), QPointF( (double)(m_imgwidth)  / 2.0 - rad2Pixel * ( centerLon - M_PI ) + m_offset, boundingPolygon.at(0).y() ) ) ) 
-                || visibleArea.intersects( QRectF( QPointF( (double)(m_imgwidth)  / 2.0 - rad2Pixel * ( centerLon + M_PI )  + m_offset, boundingPolygon.at(1).y() ), boundingPolygon.at(0) ) ) ) ) 
-                );
+		      && ( visibleArea.intersects( QRectF( boundingPolygon.at(1),
+                                                           QPointF( (qreal)(m_imgwidth) / 2.0
+                                                                    - rad2Pixel * ( centerLon - M_PI )
+                                                                    + m_offset,
+                                                                    boundingPolygon.at(0).y() ) ) )
+                           || visibleArea.intersects( QRectF( QPointF( (qreal)(m_imgwidth) / 2.0
+                                                                       - rad2Pixel * ( centerLon
+                                                                                       + M_PI )
+                                                                       + m_offset,
+                                                                       boundingPolygon.at(1).y() ),
+                                                              boundingPolygon.at(0) ) ) ) ) );
         m_offset += 4 * radius;
         boundingPolygon.translate( 4 * radius, 0 );
 
@@ -221,12 +218,12 @@ void VectorMap::rectangularCreateFromPntMap( const PntMap* pntmap,
 		|| ( (*itPolyLine)->getDateLine() == GeoPolygon::Even 
 		     && ( visibleArea.intersects(
 			    QRectF( boundingPolygon.at(1),
-				    QPointF( (double)(m_imgwidth) / 2.0
+				    QPointF( (qreal)(m_imgwidth) / 2.0
 					     - rad2Pixel * ( centerLon - M_PI )
 					     + m_offset, 
 					     boundingPolygon.at(0).y() ) ) ) 
 			  || visibleArea.intersects(
-			         QRectF( QPointF( (double)(m_imgwidth) / 2.0
+			         QRectF( QPointF( (qreal)(m_imgwidth) / 2.0
 						  - rad2Pixel * ( centerLon + M_PI )
 						  + m_offset,
 						  boundingPolygon.at(1).y() ),
@@ -254,25 +251,23 @@ void VectorMap::mercatorCreateFromPntMap( const PntMap* pntmap,
     int  radius = viewport->radius();
 
     // Calculate translation of center point
-    double  centerLon;
-    double  centerLat;
+    qreal  centerLon;
+    qreal  centerLat;
     viewport->centerCoordinates( centerLon, centerLat );
 
-    double rad2Pixel = (float)( 2 * radius ) / M_PI;
-    double lon, lat;
-    double x, y;
+    qreal rad2Pixel = (float)( 2 * radius ) / M_PI;
+    qreal lon, lat;
+    qreal x, y;
 
     viewport->planetAxis().inverse().toMatrix( m_rotMatrix );
-    GeoPolygon::PtrVector::Iterator       itPolyLine;
+    GeoPolygon::PtrVector::ConstIterator  itPolyLine = pntmap->constBegin();
     GeoPolygon::PtrVector::ConstIterator  itEndPolyLine = pntmap->constEnd();
 
     ScreenPolygon  boundingPolygon;
     QRectF         visibleArea ( 0, 0, m_imgwidth, m_imgheight );
     const int      detail = getDetailLevel( radius );
 
-    for ( itPolyLine = const_cast<PntMap *>(pntmap)->begin();
-          itPolyLine < itEndPolyLine;
-          ++itPolyLine )
+    for (; itPolyLine != itEndPolyLine; ++itPolyLine )
     {
         // This sorts out polygons by bounding box which aren't visible at all.
         m_offset = 0;
@@ -282,10 +277,15 @@ void VectorMap::mercatorCreateFromPntMap( const PntMap* pntmap,
 
         // Let's just use the top left and the bottom right bounding box point for 
         // this projection
+
+        // rather paint an invalid line then crashing here if the boundaries are not loaded yet
+        if(boundary.size() < 3) continue;
+
         for ( int i = 1; i < 3; ++i ) {
             boundary[i]->geoCoordinates(lon, lat);
-            x = (double)(m_imgwidth)  / 2.0 + rad2Pixel * (lon - centerLon);
-            y = (double)(m_imgheight) / 2.0 - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) );
+            x = (qreal)(m_imgwidth)  / 2.0 + rad2Pixel * (lon - centerLon);
+            y = (qreal)(m_imgheight) / 2.0 - rad2Pixel * ( atanh( sin( lat ) )
+                                                           - atanh( sin( centerLat ) ) );
 
             boundingPolygon << QPointF( x, y );
         }
@@ -303,9 +303,18 @@ void VectorMap::mercatorCreateFromPntMap( const PntMap* pntmap,
         } while( ( (*itPolyLine)->getDateLine() != GeoPolygon::Even 
 		   && visibleArea.intersects( (QRectF)( boundingPolygon.boundingRect() ) ) )
 		 || ( (*itPolyLine)->getDateLine() == GeoPolygon::Even
-		      && ( visibleArea.intersects( QRectF( boundingPolygon.at(1), QPointF( (double)(m_imgwidth)  / 2.0 - rad2Pixel * ( centerLon - M_PI ) + m_offset, boundingPolygon.at(0).y() ) ) ) 
-                || visibleArea.intersects( QRectF( QPointF( (double)(m_imgwidth)  / 2.0 - rad2Pixel * ( centerLon + M_PI )  + m_offset, boundingPolygon.at(1).y() ), boundingPolygon.at(0) ) ) ) ) 
-                );
+		      && ( visibleArea.intersects( QRectF( boundingPolygon.at(1),
+                                                           QPointF( (qreal)(m_imgwidth) / 2.0
+                                                                    - rad2Pixel * ( centerLon
+                                                                                    - M_PI )
+                                                                    + m_offset,
+                                                                    boundingPolygon.at(0).y() ) ) )
+                           || visibleArea.intersects( QRectF( QPointF( (qreal)(m_imgwidth) / 2.0
+                                                                       - rad2Pixel * ( centerLon
+                                                                                       + M_PI )
+                                                                       + m_offset,
+                                                                       boundingPolygon.at(1).y() ),
+                                                              boundingPolygon.at(0) ) ) ) ) );
         m_offset += 4 * radius;
         boundingPolygon.translate( 4 * radius, 0 );
 
@@ -316,12 +325,12 @@ void VectorMap::mercatorCreateFromPntMap( const PntMap* pntmap,
 		|| ( (*itPolyLine)->getDateLine() == GeoPolygon::Even 
 		     && ( visibleArea.intersects(
 			    QRectF( boundingPolygon.at(1),
-				    QPointF( (double)(m_imgwidth) / 2.0
+				    QPointF( (qreal)(m_imgwidth) / 2.0
 					     - rad2Pixel * ( centerLon - M_PI )
 					     + m_offset, 
 					     boundingPolygon.at(0).y() ) ) ) 
 			  || visibleArea.intersects(
-			         QRectF( QPointF( (double)(m_imgwidth) / 2.0
+			         QRectF( QPointF( (qreal)(m_imgwidth) / 2.0
 						  - rad2Pixel * ( centerLon + M_PI )
 						  + m_offset,
 						  boundingPolygon.at(1).y() ),
@@ -341,8 +350,8 @@ void VectorMap::mercatorCreateFromPntMap( const PntMap* pntmap,
     }
 }
 
-void VectorMap::createPolyLine( GeoDataCoordinates::Vector::ConstIterator  itStartPoint, 
-                                GeoDataCoordinates::Vector::ConstIterator  itEndPoint,
+void VectorMap::createPolyLine( GeoDataCoordinates::Vector::ConstIterator const & itStartPoint,
+                                GeoDataCoordinates::Vector::ConstIterator const & itEndPoint,
                                 const int detail, ViewportParams *viewport )
 {
     switch( viewport->projection() ) {
@@ -362,19 +371,18 @@ void VectorMap::createPolyLine( GeoDataCoordinates::Vector::ConstIterator  itSta
 }
 
 void VectorMap::sphericalCreatePolyLine(
-GeoDataCoordinates::Vector::ConstIterator  itStartPoint,
-GeoDataCoordinates::Vector::ConstIterator  itEndPoint,
+GeoDataCoordinates::Vector::ConstIterator const & itStartPoint,
+GeoDataCoordinates::Vector::ConstIterator const & itEndPoint,
 const int detail, ViewportParams *viewport )
 {
-    GeoDataCoordinates::Vector::const_iterator  itPoint;
-
     int  radius = viewport->radius();
 
-    // Quaternion qpos = ( FastMath::haveSSE() == true ) ? QuaternionSSE() : Quaternion();
     Quaternion qpos;
     //	int step = 1;
     //	int remain = size();
-    for ( itPoint = itStartPoint; itPoint != itEndPoint; ++itPoint ) {
+
+    GeoDataCoordinates::Vector::const_iterator itPoint = itStartPoint;
+    for (; itPoint != itEndPoint; ++itPoint ) {
         // remain -= step;
         if ( itPoint->detail() < detail )
             continue;
@@ -441,29 +449,28 @@ const int detail, ViewportParams *viewport )
 }
 
 void VectorMap::rectangularCreatePolyLine(
-    GeoDataCoordinates::Vector::ConstIterator  itStartPoint, 
-    GeoDataCoordinates::Vector::ConstIterator  itEndPoint,
+    GeoDataCoordinates::Vector::ConstIterator const & itStartPoint,
+    GeoDataCoordinates::Vector::ConstIterator const & itEndPoint,
     const int detail, ViewportParams *viewport )
 {
-    GeoDataCoordinates::Vector::const_iterator  itPoint;
-
     Quaternion qpos;
 
     // Calculate translation of center point
-    double  centerLon;
-    double  centerLat;
+    qreal  centerLon;
+    qreal  centerLat;
     viewport->centerCoordinates( centerLon, centerLat );
 
     // Other convenience variables
-    double  rad2Pixel = (float)( 2 * viewport->radius() ) / M_PI;
+    qreal  rad2Pixel = (float)( 2 * viewport->radius() ) / M_PI;
 
     ScreenPolygon otherPolygon;
     otherPolygon.setClosed ( m_polygon.closed() );
     bool CrossedDateline = false;
     bool firstPoint = true;
-    double lon, lat;
+    qreal lon, lat;
 
-    for ( itPoint = itStartPoint; itPoint != itEndPoint; ++itPoint ) {
+    GeoDataCoordinates::Vector::const_iterator itPoint = itStartPoint;
+    for (; itPoint != itEndPoint; ++itPoint ) {
         // remain -= step;
         if ( itPoint->detail() < detail )
 	    continue;
@@ -474,8 +481,8 @@ void VectorMap::rectangularCreatePolyLine(
 #endif
 
 	itPoint->geoCoordinates( lon, lat);
-	double x = (double)(m_imgwidth)  / 2.0 - rad2Pixel * (centerLon - lon) + m_offset;
-	double y = (double)(m_imgheight) / 2.0 + rad2Pixel * (centerLat - lat);
+	qreal x = (qreal)(m_imgwidth)  / 2.0 - rad2Pixel * (centerLon - lon) + m_offset;
+	qreal y = (qreal)(m_imgheight) / 2.0 + rad2Pixel * (centerLat - lat);
 	int currentSign = ( lon > 0.0 ) ? 1 : -1 ;
 	if ( firstPoint ) {
 	    firstPoint = false;
@@ -489,10 +496,14 @@ void VectorMap::rectangularCreatePolyLine(
 
 	    // X coordinate on the screen for the points on the
 	    // dateline on both sides of the flat map.
-	    double lastXAtDateLine = (double)(m_imgwidth) / 2.0 + rad2Pixel * ( m_lastSign * M_PI - centerLon ) + m_offset;
-	    double xAtDateLine = (double)(m_imgwidth) / 2.0 + rad2Pixel * ( -m_lastSign * M_PI - centerLon ) + m_offset;
-	    double lastYAtDateLine = (double)(m_imgheight) / 2.0 - ( m_lastLat - centerLat ) * rad2Pixel;
-	    double yAtSouthPole = (double)(m_imgheight) / 2.0 - ( -viewport->currentProjection()->maxLat() - centerLat ) * rad2Pixel;
+	    qreal lastXAtDateLine = (qreal)(m_imgwidth) / 2.0
+                + rad2Pixel * ( m_lastSign * M_PI - centerLon ) + m_offset;
+	    qreal xAtDateLine = (qreal)(m_imgwidth) / 2.0
+                + rad2Pixel * ( -m_lastSign * M_PI - centerLon ) + m_offset;
+	    qreal lastYAtDateLine = (qreal)(m_imgheight) / 2.0
+                - ( m_lastLat - centerLat ) * rad2Pixel;
+	    qreal yAtSouthPole = (qreal)(m_imgheight) / 2.0
+                - ( -viewport->currentProjection()->maxLat() - centerLat ) * rad2Pixel;
 
 	    //If the "jump" occurs in the Anctartica's latitudes
 
@@ -500,12 +511,12 @@ void VectorMap::rectangularCreatePolyLine(
 		// FIXME: This should actually need to get investigated
 		//        in GeoPainter.  For now though we just help
 		//        GeoPainter to get the clipping right.
-		if ( lastXAtDateLine > (double)(m_imgwidth) - 1.0 )
-		    lastXAtDateLine = (double)(m_imgwidth) - 1.0;
+		if ( lastXAtDateLine > (qreal)(m_imgwidth) - 1.0 )
+		    lastXAtDateLine = (qreal)(m_imgwidth) - 1.0;
 		if ( lastXAtDateLine < 0.0 )
 		    lastXAtDateLine = 0.0; 
-		if ( xAtDateLine > (double)(m_imgwidth) - 1.0 )
-		    xAtDateLine = (double)(m_imgwidth) - 1.0;
+		if ( xAtDateLine > (qreal)(m_imgwidth) - 1.0 )
+		    xAtDateLine = (qreal)(m_imgwidth) - 1.0;
 		if ( xAtDateLine < 0.0 )
 		    xAtDateLine = 0.0; 
 
@@ -548,32 +559,32 @@ void VectorMap::rectangularCreatePolyLine(
     }
 }
 
-void VectorMap::mercatorCreatePolyLine( GeoDataCoordinates::Vector::ConstIterator  itStartPoint, 
-					GeoDataCoordinates::Vector::ConstIterator  itEndPoint,
-					const int detail,
-					ViewportParams *viewport )
+void VectorMap::mercatorCreatePolyLine(
+        GeoDataCoordinates::Vector::ConstIterator const & itStartPoint,
+        GeoDataCoordinates::Vector::ConstIterator const & itEndPoint,
+        const int detail,
+        ViewportParams *viewport )
 {
-    GeoDataCoordinates::Vector::const_iterator  itPoint;
-
     Quaternion qpos;
 
     // Calculate translation of center point
-    double  centerLon;
-    double  centerLat;
+    qreal  centerLon;
+    qreal  centerLat;
     viewport->centerCoordinates( centerLon, centerLat );
 
     // Other convenience variables
-    double  rad2Pixel = (double)( 2 * viewport->radius() ) / M_PI;
+    qreal  rad2Pixel = (qreal)( 2 * viewport->radius() ) / M_PI;
 
     ScreenPolygon  otherPolygon;
     otherPolygon.setClosed ( m_polygon.closed() );
 
     bool    CrossedDateline = false;
     bool    firstPoint      = true;
-    double  lon;
-    double  lat;
+    qreal  lon;
+    qreal  lat;
 
-    for ( itPoint = itStartPoint; itPoint != itEndPoint; ++itPoint ) {
+    GeoDataCoordinates::Vector::const_iterator itPoint = itStartPoint;
+    for (; itPoint != itEndPoint; ++itPoint ) {
         // remain -= step;
         if ( itPoint->detail() < detail )
 	    continue;
@@ -584,15 +595,16 @@ void VectorMap::mercatorCreatePolyLine( GeoDataCoordinates::Vector::ConstIterato
 #endif
 
 	// FIXME: Call the projection.  Unfortunately there is no
-	//        screenCoordinates taking doubles.
+	//        screenCoordinates taking qreals.
 	itPoint->geoCoordinates( lon, lat );
 
     // Removing all points beyond +/- 85 deg for Mercator:
     if ( fabs( lat ) > viewport->currentProjection()->maxLat() )
         continue;
 
-	double x = (double)(m_imgwidth)  / 2.0 + rad2Pixel * (lon - centerLon) + m_offset;
-	double y = (double)(m_imgheight) / 2.0 - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) );
+	qreal x = (qreal)(m_imgwidth)  / 2.0 + rad2Pixel * (lon - centerLon) + m_offset;
+	qreal y = (qreal)(m_imgheight) / 2.0
+            - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) );
 	int currentSign = ( lon > 0.0 ) ? 1 : -1 ;
 	if ( firstPoint ) {
 	    firstPoint = false;
@@ -608,10 +620,17 @@ void VectorMap::mercatorCreatePolyLine( GeoDataCoordinates::Vector::ConstIterato
 	    // x coordinate on the screen for the points on the dateline on both
 	    // sides of the flat map.
 	    // FIXME: mercator projection here too.
-	    double lastXAtDateLine = (double)(m_imgwidth) / 2.0 + rad2Pixel * ( m_lastSign * M_PI - centerLon ) + m_offset;
-	    double xAtDateLine = (double)(m_imgwidth) / 2.0 + rad2Pixel * ( -m_lastSign * M_PI - centerLon ) + m_offset;
-        double lastYAtDateLine = (double)( viewport->height() / 2 - rad2Pixel * ( atanh( sin( m_lastLat ) ) - atanh( sin( centerLat ) ) ) );
-        double yAtSouthPole = (double)( viewport->height() / 2 - rad2Pixel * ( atanh( sin( -viewport->currentProjection()->maxLat() ) ) - atanh( sin( centerLat ) ) ) );
+	    qreal lastXAtDateLine = (qreal)(m_imgwidth) / 2.0
+                + rad2Pixel * ( m_lastSign * M_PI - centerLon ) + m_offset;
+	    qreal xAtDateLine = (qreal)(m_imgwidth) / 2.0
+                + rad2Pixel * ( -m_lastSign * M_PI - centerLon ) + m_offset;
+        qreal lastYAtDateLine = (qreal)( viewport->height() / 2 - rad2Pixel
+                                         * ( atanh( sin( m_lastLat ) )
+                                             - atanh( sin( centerLat ) ) ) );
+        qreal yAtSouthPole = (qreal)( viewport->height() / 2
+                                      - rad2Pixel * ( atanh( sin( -viewport->currentProjection()->
+                                                                  maxLat() ) )
+                                                      - atanh( sin( centerLat ) ) ) );
 
 	    //If the "jump" occurs in the Anctartica's latitudes
 
@@ -619,12 +638,12 @@ void VectorMap::mercatorCreatePolyLine( GeoDataCoordinates::Vector::ConstIterato
 		// FIXME: This should actually need to get investigated
 		//        in GeoPainter.  For now though we just help
 		//        GeoPainter to get the clipping right.
-		if ( lastXAtDateLine > (double)(m_imgwidth) - 1.0 )
-		    lastXAtDateLine = (double)(m_imgwidth) - 1.0;
+		if ( lastXAtDateLine > (qreal)(m_imgwidth) - 1.0 )
+		    lastXAtDateLine = (qreal)(m_imgwidth) - 1.0;
 		if ( lastXAtDateLine < 0.0 )
 		    lastXAtDateLine = 0.0; 
-		if ( xAtDateLine > (double)(m_imgwidth) - 1.0 )
-		    xAtDateLine = (double)(m_imgwidth) - 1.0;
+		if ( xAtDateLine > (qreal)(m_imgwidth) - 1.0 )
+		    xAtDateLine = (qreal)(m_imgwidth) - 1.0;
 		if ( xAtDateLine < 0.0 )
 		    xAtDateLine = 0.0; 
 
@@ -672,17 +691,15 @@ void VectorMap::mercatorCreatePolyLine( GeoDataCoordinates::Vector::ConstIterato
 //
 // FIXME: This is a strange thing to have in the vector code. 
 //        Move it somewhere better.
-// FIXME: Btw, we shouldn't assume that the globe to paint is the earth.
 //
 void VectorMap::paintBase( GeoPainter * painter, ViewportParams* viewport,
 			   bool antialiasing )
 {
-    // The paintBase function is projection dependent, and it's not
-    // just a mathematical conversion, so it's located in the
-    // projection helper.
-    viewport->currentProjection()->helper()->paintBase( painter, viewport,
-							m_pen, m_brush,
-							antialiasing );
+    painter->setRenderHint( QPainter::Antialiasing, antialiasing );
+    painter->setPen( m_pen );
+    painter->setBrush( m_brush );
+
+    painter->drawPath( viewport->currentProjection()->mapShape( viewport ) );
 }
 
 
@@ -708,8 +725,8 @@ void VectorMap::drawMap( QPaintDevice *origimg, bool antialiasing,
     painter.setPen( m_pen );
     painter.setBrush( m_brush );
 
-    ScreenPolygon::Vector::const_iterator  itEndPolygon = end();
-    for ( ScreenPolygon::Vector::const_iterator itPolygon = begin();
+    ScreenPolygon::Vector::const_iterator  itEndPolygon = constEnd();
+    for ( ScreenPolygon::Vector::const_iterator itPolygon = constBegin();
           itPolygon != itEndPolygon; 
           ++itPolygon )
     {
@@ -730,13 +747,13 @@ void VectorMap::paintMap(GeoPainter * painter, bool antialiasing)
     painter->setPen( m_pen );
     painter->setBrush( m_brush );
 
-    ScreenPolygon::Vector::const_iterator  itEndPolygon = end();
+    ScreenPolygon::Vector::const_iterator  itEndPolygon = constEnd();
 
-    for ( ScreenPolygon::Vector::const_iterator itPolygon = begin();
+    for ( ScreenPolygon::Vector::const_iterator itPolygon = constBegin();
           itPolygon != itEndPolygon;
           ++itPolygon )
     {
-        if ( itPolygon->closed() == true )  
+        if ( itPolygon->closed() )
             painter->drawPolygon( *itPolygon );
         else
             painter->drawPolyline( *itPolygon );
@@ -747,13 +764,13 @@ void VectorMap::paintMap(GeoPainter * painter, bool antialiasing)
 void VectorMap::manageCrossHorizon()
 {
     // qDebug("Crossing horizon line");
-    // if (currentlyvisible == false) qDebug("Leaving visible hemisphere");
+    // if (!currentlyvisible) qDebug("Leaving visible hemisphere");
     // else qDebug("Entering visible hemisphere");
 
-    if ( m_horizonpair == false ) {
+    if ( !m_horizonpair ) {
         // qDebug("Point A");
 
-        if ( m_currentlyvisible == false ) {
+        if ( !m_currentlyvisible ) {
             m_horizona    = horizonPoint();
             m_horizonpair = true;
         }
@@ -776,15 +793,15 @@ void VectorMap::manageCrossHorizon()
 const QPointF VectorMap::horizonPoint()
 {
     // qDebug("Interpolating");
-    double  xa;
-    double  ya;
+    qreal  xa;
+    qreal  ya;
 
     xa = m_currentPoint.x() - ( m_imgrx + 1 );
 
     // Move the currentPoint along the y-axis to match the horizon.
-    //	ya = sqrt( ((double)m_radius + 1) * ( (double)m_radius + 1) - xa*xa);
+    //	ya = sqrt( ((qreal)m_radius + 1) * ( (qreal)m_radius + 1) - xa*xa);
     ya = ( m_rlimit > xa * xa )
-        ? sqrt( (double)(m_rlimit) - (double)( xa * xa ) ) : 0;
+        ? sqrt( (qreal)(m_rlimit) - (qreal)( xa * xa ) ) : 0;
     // qDebug() << " m_rlimit" << m_rlimit << " xa*xa" << xa*xa << " ya: " << ya;
     if ( ( m_currentPoint.y() - ( m_imgry + 1 ) ) < 0 )
         ya = -ya; 
@@ -796,20 +813,20 @@ const QPointF VectorMap::horizonPoint()
 void VectorMap::createArc()
 {
 
-    double  beta  = (double)( RAD2DEG 
+    qreal  beta  = (qreal)( RAD2DEG 
 			      * atan2( m_horizonb.y() - m_imgry - 1,
 				       m_horizonb.x() - m_imgrx - 1 ) );
-    double  alpha = (double)( RAD2DEG
+    qreal  alpha = (qreal)( RAD2DEG
 			      * atan2( m_horizona.y() - m_imgry - 1,
 				       m_horizona.x() - m_imgrx - 1 ) );
 
-    double diff = beta - alpha;
+    qreal diff = beta - alpha;
 
     if ( diff != 0.0 && diff != 180.0 && diff != -180.0 ) {
 
         m_polygon.append( m_horizona );
 
-        double sgndiff = diff / fabs(diff);
+        qreal sgndiff = diff / fabs(diff);
 
         if (fabs(diff) > 180.0)
             diff = - sgndiff * (360.0 - fabs(diff));
@@ -822,11 +839,11 @@ void VectorMap::createArc()
 	
         int  itx;
         int  ity;
-        // qDebug() << "r: " << (m_radius+1) << "rn: " << sqrt((double)(m_rlimit));
-        double  arcradius = sqrt( (double)( m_rlimit ) );
+        // qDebug() << "r: " << (m_radius+1) << "rn: " << sqrt((qreal)(m_rlimit));
+        qreal  arcradius = sqrt( (qreal)( m_rlimit ) );
 
         for ( int it = 1; it < fabs(diff); ++it ) {
-            double angle = DEG2RAD * (double)( alpha + (sgndiff * it) );
+            qreal angle = DEG2RAD * (qreal)( alpha + (sgndiff * it) );
             itx = (int)( m_imgrx +  arcradius * cos( angle ) + 1 );
             ity = (int)( m_imgry +  arcradius * sin( angle ) + 1 );
             // qDebug() << " ity: " << ity;
