@@ -15,11 +15,14 @@
 #include <QtCore/QDebug>
 #include <QtCore/QRect>
 
+#include <QtGui/QPainterPath>
+#include <QtGui/QPainterPathStroker>
+#include <QtGui/QRegion>
+
 #include "SphericalProjection.h"
 #include "EquirectProjection.h"
 #include "MercatorProjection.h"
 
-#include "AbstractProjectionHelper.h"
 
 namespace Marble
 {
@@ -38,12 +41,15 @@ public:
     Quaternion           m_planetAxis;   // Position, coded in a quaternion
     mutable matrix       m_planetAxisMatrix;
     int                  m_radius;       // Zoom level (pixels / globe radius)
+    qreal                m_angularResolution;
 
     QSize                m_size;         // width, height
 
-    // FIXME: The usage of the class BoundingBox as a whole is DEPRECATED
-    //        Please use the class GeoDataLatLon(Alt)Box instead! 
-    BoundingBox m_boundingBox;  // What the view currently can see
+
+    bool                 m_dirtyBox;
+    GeoDataLatLonAltBox  m_viewLatLonAltBox;
+    bool                 m_dirtyRegion;
+    QRegion              m_activeRegion;
 
     static SphericalProjection  s_sphericalProjection;
     static EquirectProjection   s_equirectProjection;
@@ -57,7 +63,10 @@ ViewportParamsPrivate::ViewportParamsPrivate()
       m_planetAxisMatrix(),
       m_radius( 2000 ),
       m_size( 100, 100 ),
-      m_boundingBox()
+      m_dirtyBox( true ),
+      m_viewLatLonAltBox(),
+      m_dirtyRegion( true ),
+      m_activeRegion()
 {
 } 
 
@@ -97,6 +106,9 @@ AbstractProjection *ViewportParams::currentProjection() const
 
 void ViewportParams::setProjection(Projection newProjection)
 {
+    d->m_dirtyBox = true;
+    d->m_dirtyRegion = true;
+
     d->m_projection = newProjection;
 
     // Set the pointer to the current projection class.
@@ -112,11 +124,7 @@ void ViewportParams::setProjection(Projection newProjection)
         break;
     }
 
-    // Adjust the active Region
-    currentProjection()->helper()->createActiveRegion( this );
-    currentProjection()->helper()->createProjectedRegion( this );
-
-    // We now need to reset the planetAxis to make sure 
+    // We now need to reset the planetAxis to make sure
     // that it's a valid axis orientation!
     // So this line is important (although it might look odd) ! :
     setPlanetAxis( planetAxis() );
@@ -130,8 +138,8 @@ int ViewportParams::polarity() const
     GeoDataCoordinates southPole( 0.0, -currentProjection()->maxLat() );
 
     bool globeHidesN, globeHidesS;
-    int x;
-    int yN, yS;
+    qreal x;
+    qreal yN, yS;
 
     currentProjection()->screenCoordinates( northPole, this,
                                           x, yN, globeHidesN );
@@ -174,11 +182,11 @@ int ViewportParams::radius() const
 
 void ViewportParams::setRadius(int newRadius)
 {
-    d->m_radius = newRadius;
+    d->m_dirtyBox = true;
+    d->m_dirtyRegion = true;
 
-    // Adjust the active Region
-    currentProjection()->helper()->createActiveRegion( this );
-    currentProjection()->helper()->createProjectedRegion( this );
+    d->m_radius = newRadius;
+    d->m_angularResolution = 0.25 * M_PI / fabs( (qreal)(d->m_radius) );
 }
 
 bool ViewportParams::globeCoversViewport() const
@@ -204,6 +212,9 @@ Quaternion ViewportParams::planetAxis() const
 
 bool ViewportParams::setPlanetAxis(const Quaternion &newAxis)
 {
+    d->m_dirtyBox = true;
+    d->m_dirtyRegion = true;
+
     bool valid = true;
 
     qreal maxLat = currentProjection()->maxLat();
@@ -215,7 +226,7 @@ bool ViewportParams::setPlanetAxis(const Quaternion &newAxis)
     // This is should not be done for projections where the
     // maximum latitude is traversable (e.g. for a sphere).
 
-    if ( !currentProjection()->traversableMaxLat() && fabs( newAxis.pitch() ) > maxLat ) {
+    if ( !currentProjection()->traversablePoles() && fabs( newAxis.pitch() ) > maxLat ) {
 
         qreal centerLon, centerLat;
         centerCoordinates( centerLon, centerLat );
@@ -239,10 +250,6 @@ bool ViewportParams::setPlanetAxis(const Quaternion &newAxis)
     // creating matching planetAxis matrix
     planetAxis().inverse().toMatrix( d->m_planetAxisMatrix );
 
-    // Adjust the projected and active Region
-    currentProjection()->helper()->createActiveRegion( this );
-    currentProjection()->helper()->createProjectedRegion( this );
-
     return valid;
 }
 
@@ -269,39 +276,26 @@ QSize ViewportParams::size() const
 
 void ViewportParams::setWidth(int newWidth)
 {
-    d->m_size.setWidth( newWidth );
+    d->m_dirtyBox = true;
+    d->m_dirtyRegion = true;
 
-    // Adjust the active Region
-    currentProjection()->helper()->createActiveRegion( this );
-    currentProjection()->helper()->createProjectedRegion( this );
+    d->m_size.setWidth( newWidth );
 }
 
 void ViewportParams::setHeight(int newHeight)
 {
-    d->m_size.setHeight( newHeight );
+    d->m_dirtyBox = true;
+    d->m_dirtyRegion = true;
 
-    // Adjust the active Region
-    currentProjection()->helper()->createActiveRegion( this );
-    currentProjection()->helper()->createProjectedRegion( this );
+    d->m_size.setHeight( newHeight );
 }
 
 void ViewportParams::setSize(QSize newSize)
 {
+    d->m_dirtyBox = true;
+    d->m_dirtyRegion = true;
+
     d->m_size = newSize;
-
-    // Adjust the active Region
-    currentProjection()->helper()->createActiveRegion( this );
-    currentProjection()->helper()->createProjectedRegion( this );
-}
-
-BoundingBox ViewportParams::boundingBox() const
-{
-    return d->m_boundingBox;
-}
-
-void ViewportParams::setBoundingBox( const BoundingBox & boundingBox )
-{
-    d->m_boundingBox = boundingBox;
 }
 
 // ================================================================
@@ -322,16 +316,22 @@ void ViewportParams::centerCoordinates( qreal &centerLon, qreal &centerLat ) con
 
 GeoDataLatLonAltBox ViewportParams::viewLatLonAltBox() const
 {
-    return d->m_currentProjection->latLonAltBox( QRect( QPoint( 0, 0 ), 
+    if (d->m_dirtyBox) {
+        d->m_viewLatLonAltBox = d->m_currentProjection->latLonAltBox( QRect( QPoint( 0, 0 ), 
                         d->m_size ),
                         this );
+        d->m_dirtyBox = false;
+    }
+
+    return d->m_viewLatLonAltBox;
 }
 
 qreal ViewportParams::angularResolution() const
 {
     // We essentially divide the diameter by 180 deg and
     // take half of the result as a guess for the angle per pixel resolution. 
-    return 0.25 * M_PI / fabs( (qreal)(d->m_radius) );
+    // d->m_angularResolution = 0.25 * M_PI / fabs( (qreal)(d->m_radius);
+    return d->m_angularResolution;
 }
 
 bool ViewportParams::resolves ( const GeoDataLatLonBox &latLonBox ) const
@@ -339,6 +339,14 @@ bool ViewportParams::resolves ( const GeoDataLatLonBox &latLonBox ) const
     return latLonBox.width() + latLonBox.height() > 2.0 * angularResolution();
 }
 
+
+bool ViewportParams::resolves ( const GeoDataLatLonAltBox &latLonAltBox ) const
+{
+    return    latLonAltBox.width() + latLonAltBox.height() > 2.0 * angularResolution()
+           || latLonAltBox.maxAltitude() - latLonAltBox.minAltitude() > 10000;
+           
+}
+
 bool ViewportParams::resolves ( const GeoDataCoordinates &coord1, 
                                 const GeoDataCoordinates &coord2 ) const
 {
@@ -357,4 +365,26 @@ bool  ViewportParams::mapCoversViewport() const
     return d->m_currentProjection->mapCoversViewport( this );
 }
 
+QRegion ViewportParams::activeRegion() const
+{
+    if (d->m_dirtyRegion) {
+        // Take the mapShape and subtract a stroke that is twice as wide as the
+        // navigation strip:
+        qreal navigationStrip = 25;
+
+        QPainterPath mapShape = d->m_currentProjection->mapShape( this );
+
+        QPainterPathStroker mapShapeStroke;
+        mapShapeStroke.setWidth( 2.0 * navigationStrip );
+        QPainterPath mapShapeStrokePath = mapShapeStroke.createStroke( mapShape );
+
+        QPainterPath activeShape = mapShape.subtracted( mapShapeStrokePath );
+        d->m_activeRegion = QRegion( activeShape.boundingRect().toRect() );
+        d->m_dirtyRegion = false;
+    }
+
+    return d->m_activeRegion;
+}
+
+
 }
