@@ -25,12 +25,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlHeadingTagHandler : public GeoTagHandler {
-public:
-    DgmlHeadingTagHandler();
-    virtual ~DgmlHeadingTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlHeadingTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlHeadingTagHandler_h
