@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmloutlineTagHandler : public GeoTagHandler {
-public:
-    KmloutlineTagHandler();
-    virtual ~KmloutlineTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmloutlineTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmloutlineTagHandler_h
