@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlSimpleFieldTagHandler : public GeoTagHandler {
-public:
-    KmlSimpleFieldTagHandler();
-    virtual ~KmlSimpleFieldTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlSimpleFieldTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlSimpleFieldTagHandler_h
