@@ -94,8 +94,8 @@ bool GeoParser::read( QIODevice* device )
 
                 if ( !m_nodeStack.isEmpty() )
                     raiseError(
-                        QObject::tr("Parsing failed. Still %1 unclosed tags after document end.")
-                        .arg( m_nodeStack.size() ));
+                        QObject::tr("Parsing failed. Still %n unclosed tag(s) after document end.", "",
+                        m_nodeStack.size() ) + errorString());
             } else
                 raiseDocumentElementError();
         }
@@ -124,7 +124,12 @@ GeoStackItem GeoParser::parentElement( unsigned int depth )
 
 void GeoParser::parseDocument()
 {
-    Q_ASSERT( isStartElement() );
+    if( !isStartElement() ) {
+        raiseError( QString("Error parsing file at line: %1 and column %2 . ")
+                    .arg( lineNumber() ).arg( columnNumber() )
+                    +  QString("This is an Invalid File") );
+        return;
+    }
 
     while ( !atEnd() ) {
         readNext();
@@ -155,7 +160,7 @@ void GeoParser::parseDocument()
             // DGMLNameTagHandler assumes that <name> only contains textual
             // children, and reads the joined value of all children using
             // readElementText(). This implicates that tags like <name>
-            // don't contain any children that would need to be procesed using
+            // don't contain any children that would need to be processed using
             // this parseDocument() function.
             if ( processChildren ) {
                 m_nodeStack.push( stackItem );
