@@ -50,9 +50,6 @@ class Track : public AbstractLayerContainer,
     virtual void draw(ClipPainter *painter, 
                       const QSize &canvasSize, 
                       ViewParams *viewParams );
-    virtual void draw(ClipPainter *painter, 
-                      const QSize &canvasSize, ViewParams *viewParams,
-                      const BoundingBox &box);
     virtual void draw( ClipPainter*, const QPoint& );
     
     virtual void printToStream( QTextStream& ) const;
