@@ -14,6 +14,9 @@
 #include "AbstractLayerContainer.h"
 #include "AbstractLayerData.h"
 
+namespace Marble
+{
+
 /**
  * @brief uninterupted sequence of trackPoints
  * 
@@ -26,9 +29,6 @@ class TrackSegment : public AbstractLayerContainer,
 {
  public:
     TrackSegment();
-    virtual void draw(ClipPainter *painter, 
-                      const QSize &canvasSize, ViewParams *viewParams,
-                      const BoundingBox &box );
     virtual void draw(ClipPainter *painter, 
                       const QSize &canvasSize,
                       ViewParams *viewParams );
@@ -36,8 +36,9 @@ class TrackSegment : public AbstractLayerContainer,
     void drawArrow( ClipPainter*,  QPointF,  QPointF );
     
     virtual void printToStream( QTextStream & ) const;
-
 };
 
+}
+
 #endif
 
